@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 PXMLVIEW.PY
 Copyright (C) 2008-2011 by Peter A. Donis
@@ -149,23 +150,22 @@ class XMLTabWidget(gui.PTabWidget):
         self._parent.statusbar.set_text(text)
 
 
-PXMLViewerAboutData = {
-    'name': "PXMLViewer",
-    'version': version.version_string(__version__),
-    'copyright': "Copyright (C) 2008-2011 by Peter A. Donis",
-    'license': "GNU General Public License (GPL) Version 2",
-    'description': "XML File Viewer", 
-    'developers': ["Peter Donis"],
-    'website': "http://www.peterdonis.net",
-    'icon': os.path.join(os.path.split(os.path.realpath(__file__))[0],
-        "pxmlview.png") }
-
-
 class PXMLViewer(gui.PMainWindow):
     
-    aboutdata = PXMLViewerAboutData
+    aboutdata = {
+        'name': "PXMLViewer",
+        'version': version.version_string(__version__),
+        'copyright': "Copyright (C) 2008-2011 by Peter A. Donis",
+        'license': "GNU General Public License (GPL) Version 2",
+        'description': "XML File Viewer", 
+        'developers': ["Peter Donis"],
+        'website': "http://www.peterdonis.net",
+        'icon': os.path.join(os.path.split(os.path.realpath(__file__))[0],
+            "pxmlview.png") }
+    
     actionflags = [ACTION_FILEOPEN, ACTION_ABOUT, ACTION_ABOUTTOOLKIT,
         ACTION_EXIT]
+    
     clientwidgetclass = XMLTabWidget
     defaultcaption = "XML File Viewer"
     large_icons = True
