@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 PYIDSERVER-GUI.PY
 Copyright (C) 2008-2011 by Peter A. Donis
@@ -80,8 +81,8 @@ class chat_replies(NotifierClient, _old_chat_replies):
     
     instance = None
     
-    def __init__(self, addr, items, fileobj, callback=None):
-        _old_chat_replies.__init__(self, addr, items, fileobj, callback)
+    def __init__(self, addr, items, callback=None):
+        _old_chat_replies.__init__(self, addr, items, callback)
         chat_replies.instance = self
     
     def close(self):
@@ -91,93 +92,78 @@ class chat_replies(NotifierClient, _old_chat_replies):
 pyidserver.chat_replies = chat_replies
 
 
-# Nested child lists for panels
-
-IDServerPadding = [] # equates to an empty panel when processed
-
-IDServerTopLeft = [
-    # No event handler by default for an edit box, and the signal we want to
-    # bind to (the Enter key) isn't the default signal anyway, so no event
-    # handler here
-    get_editbox('url') ]
-IDServerTopRight = [
-    # This action button has a non-standard name, so we have to specify it;
-    # the ``go`` method of the main panel then becomes the target (buttons and
-    # action buttons are the only spec controls that automatically assume they
-    # have targets; this seems reasonable since that's what buttons are for)
-    get_action_button(ACTION_OK, 'go') ]
-IDServerTopPanel = [
-    get_interior_panel(
-        IDServerTopLeft, ALIGN_JUST, LAYOUT_HORIZONTAL, 'left'),
-    get_interior_panel(
-        IDServerTopRight, ALIGN_RIGHT, LAYOUT_HORIZONTAL, 'right') ]
-
-IDServerMainControls = [
-    # The empty string after each check box name means that the target event
-    # handler method will be named ``<name>_check``, where ``<name>`` is the
-    # base name of the control (the 2nd parameter)--note that in the specs code
-    # the actual full name of the control will be ``checkbox_<name>``, to avoid
-    # name collisions between controls of different types; for the combo box,
-    # the handler method name will be ``<name>_selected``
-    get_checkbox("DNS Only", 'dnsonly', ''),
-    get_checkbox("Set Protocol", 'protocol', ''),
-    get_combobox(sorted(pyidserver.protocols.iterkeys()), 'protocol', ''),
-    get_checkbox("Set Port", 'portnum', ''),
-    # No handler for the numedit, just need to keep it at a fixed size
-    get_numeditbox('portnum', expand=False) ]
-IDServerMainHeader = [
-    get_toplevel_panel(
-        IDServerMainControls, ALIGN_LEFT, LAYOUT_HORIZONTAL, 'controls'),
-    get_padding('main') ]
-IDServerMainBody = [
-    # No event handler for the text control (since it's display-only anyway)
-    get_textcontrol('output') ]
-IDServerMainPanel = [
-    get_midlevel_panel(
-        IDServerMainHeader, ALIGN_TOP, LAYOUT_HORIZONTAL, 'header'),
-    get_interior_panel(
-        IDServerMainBody, ALIGN_JUST, LAYOUT_VERTICAL, 'body') ]
-
-IDServerBottomPanel = [
-    get_padding('bottom'),
-    # These action buttons all have their standard names, so no additional
-    # parameters are needed; each one's target will be the method with its
-    # name: ``about``, ``about_toolkit``, and ``exit`` (note that the ``exit``
-    # method is in the parent, which is the main window, not the main panel
-    # itself; the automatic lookup method finds it by traversing the parent
-    # tree if the method is not found in the panel)
-    get_action_button(ACTION_ABOUT),
-    get_action_button(ACTION_ABOUTTOOLKIT),
-    get_action_button(ACTION_EXIT) ]
-
-IDServerPanels = [
-    get_toplevel_panel(
-        IDServerTopPanel, ALIGN_TOP, LAYOUT_HORIZONTAL, 'top'),
-    get_toplevel_panel(
-        IDServerMainPanel, ALIGN_JUST, LAYOUT_VERTICAL, 'main'),
-    get_toplevel_panel(
-        IDServerBottomPanel, ALIGN_BOTTOM, LAYOUT_HORIZONTAL, 'bottom') ]
-
-IDServerAboutData = {
-    'name': "PyIDServer",
-    'version': version.version_string(__version__),
-    'copyright': "Copyright (C) 2008-2011 by Peter A. Donis",
-    'license': "GNU General Public License (GPL) Version 2",
-    'description': "A Python GUI for IDServer", 
-    'developers': ["Peter Donis"],
-    'website': "http://www.peterdonis.net",
-    'icon': os.path.join(os.path.split(os.path.realpath(__file__))[0],
-        "pyidserver.png") }
-
-
 class IDServerFrame(gui.PMainPanel):
     
-    aboutdata = IDServerAboutData
+    aboutdata = {
+        'name': "PyIDServer",
+        'version': version.version_string(__version__),
+        'copyright': "Copyright (C) 2008-2011 by Peter A. Donis",
+        'license': "GNU General Public License (GPL) Version 2",
+        'description': "A Python GUI for IDServer", 
+        'developers': ["Peter Donis"],
+        'website': "http://www.peterdonis.net",
+        'icon': os.path.join(os.path.split(os.path.realpath(__file__))[0],
+            "pyidserver.png") }
+    
     defaultcaption = "PyIDServer"
     layout = LAYOUT_VERTICAL
     placement = (SIZE_CLIENTWRAP, MOVE_CENTER)
     
-    childlist = IDServerPanels
+    childlist = [
+        toplevel_panel(ALIGN_TOP, LAYOUT_HORIZONTAL, 'top', [
+            interior_panel(ALIGN_JUST, LAYOUT_HORIZONTAL, 'left', [
+                # No standard event handler for this edit box (the signal
+                # we want to bind to, the Enter key, isn't the standard
+                # one for an edit box, so we'll do the binding by hand
+                # below); note that the automatic lookup code for event
+                # handlers (see below) does nothing if no matching handler
+                # is found (this makes declaring the GUI a lot easier since
+                # you don't have to duplicate knowledge of which controls
+                # have handlers, just declare the ones you want as methods)
+                editbox('url') ]),
+            interior_panel(ALIGN_RIGHT, LAYOUT_HORIZONTAL, 'right', [
+                # This action button has a non-standard name, so we have to
+                # specify it; the ``go`` method of the main panel then becomes
+                # the target (buttons and action buttons are the only spec
+                # controls that automatically assume they have targets; this
+                # seems reasonable since that's what buttons are for)
+                action_button(ACTION_OK, 'go') ]) ]),
+        toplevel_panel(ALIGN_JUST, LAYOUT_VERTICAL, 'main', [
+            midlevel_panel(ALIGN_TOP, LAYOUT_HORIZONTAL, 'header', [
+                toplevel_panel(ALIGN_LEFT, LAYOUT_HORIZONTAL, 'controls', [
+                    # Each control below will automatically look for its
+                    # event handler; the target method for check boxes is
+                    # ``<name>_check``, where ``<name>`` is the base name of
+                    # the control (the 2nd parameter)--note that in the specs
+                    # code the actual full name of the control will be
+                    # ``checkbox_<name>``, to avoid name collisions between
+                    # controls of different types; for the combo box, the
+                    # handler method name will be ``<name>_selected``
+                    checkbox("DNS Only", 'dnsonly'),
+                    checkbox("Set Protocol", 'protocol'),
+                    combobox('protocol',
+                        sorted(pyidserver.protocols.iterkeys())),
+                    checkbox("Set Port", 'portnum'),
+                    # No handler for the numedit, just need to keep it at a
+                    # fixed size
+                    numeditbox('portnum', expand=False) ]),
+                padding('main') ]),
+            interior_panel(ALIGN_JUST, LAYOUT_VERTICAL, 'body', [
+                # No event handler for the text control (since it's
+                # display-only anyway)
+                textcontrol('output') ]) ]),
+        toplevel_panel(ALIGN_BOTTOM, LAYOUT_HORIZONTAL, 'bottom', [
+            padding('bottom'),
+            # These action buttons all have their standard names, so no
+            # additional parameters are needed; each one's target will be the
+            # method with its name: ``about``, ``about_toolkit``, and
+            # ``exit`` (note that the ``exit`` method is in the parent, which
+            # is the main window, not the main panel itself; the automatic
+            # lookup method finds it by traversing the parent tree if the
+            # method is not found in the panel)
+            action_button(ACTION_ABOUT),
+            action_button(ACTION_ABOUTTOOLKIT),
+            action_button(ACTION_EXIT) ]) ]
     
     query_in_progress = False
     
@@ -187,34 +173,27 @@ class IDServerFrame(gui.PMainPanel):
         
         # The function we're wrapping with our GUI, and its default parameters
         self.func = pyidserver.run_main
-        _, dns_only, protocol, portnum = self.func.func_defaults
         
         # Controls affected by the DNS Only checkbox
         self.dnsonly_controls = (
             (self.checkbox_protocol, self.combo_protocol),
             (self.checkbox_portnum, self.edit_portnum) )
         
-        # Controls that should be disabled while query is in progress
-        self.go_disabled_controls = (
-            self.edit_url,
-            self.checkbox_dnsonly,
-            self.checkbox_protocol,
-            self.combo_protocol,
-            self.checkbox_portnum,
-            self.edit_portnum )
+        # Controls independent of DNS Only checkbox
+        self.other_controls = (
+            self.edit_url, self.checkbox_dnsonly)
         
         # Adjust some widget parameters that couldn't be set in constructors
         self.edit_url.setup_notify(SIGNAL_ENTER, self.go)
         
-        self.checkbox_dnsonly.checked = dns_only
+        self.checkbox_dnsonly.checked = self.default_dnsonly()
         self.dnsonly_check() # technically not needed, put in for completeness
         
-        if protocol == "":
-            protocol = pyidserver.PROTO_DEFAULT
-        self.combo_protocol.set_current_text(protocol)
+        self.combo_protocol.set_current_text(
+            self.default_protocol() or pyidserver.PROTO_DEFAULT)
         self.protocol_check()
         
-        self.edit_portnum.edit_text = str(portnum)
+        self.edit_portnum.edit_text = str(self.default_portnum())
         self.portnum_check()
         
         self.text_output.set_font("Courier New")
@@ -225,6 +204,15 @@ class IDServerFrame(gui.PMainPanel):
         # Start with keyboard focus in the URL text entry
         self.edit_url.set_focus()
     
+    def default_dnsonly(self):
+        return self.func.func_defaults[2]
+    
+    def default_protocol(self):
+        return self.func.func_defaults[3]
+    
+    def default_portnum(self):
+        return self.func.func_defaults[4]
+    
     def dnsonly_check(self):
         """Called when the dns_only checkbox is checked/unchecked.
         
@@ -257,7 +245,7 @@ class IDServerFrame(gui.PMainPanel):
         self.edit_portnum.enabled = self.checkbox_portnum.checked
     
     def go(self):
-        """Called when the Go button is pushed.
+        """Called when the Go/Stop button is pushed.
         
         Execute the idserver query, or stop a query in progress.
         For executing a query, this method is also called when the
@@ -284,28 +272,30 @@ class IDServerFrame(gui.PMainPanel):
             if self.checkbox_protocol.checked:
                 protocol = self.combo_protocol.current_text()
             else:
-                protocol = self.func.func_defaults[2]
+                protocol = self.default_protocol()
             if self.checkbox_portnum.checked:
                 portnum = int(self.edit_portnum.edit_text)
             else:
-                portnum = self.func.func_defaults[3]
+                portnum = self.default_portnum()
             
             # Now execute
-            for control in self.go_disabled_controls:
-                control.enabled = False
+            for ctrl, subctrl in self.dnsonly_controls:
+                ctrl.enabled = subctrl.enabled = False
+            for ctrl in self.other_controls:
+                ctrl.enabled = False
             self.button_go.set_caption(CAPTION_STOP)
             self.button_go.set_icon(ICON_STOP)
             self.query_in_progress = True
             
-            self.func(self.outputfile, url,
+            self.func(url, outfile=self.outputfile,
                 dns_only=dns_only, protocol=protocol, portnum=portnum)
         
         # Either we're done, or we've stopped a query in progress
         self.query_in_progress = False
         self.button_go.set_caption(CAPTION_GO)
         self.button_go.set_icon(ICON_GO)
-        self.edit_url.enabled = True
-        self.checkbox_dnsonly.enabled = True
+        for ctrl in self.other_controls:
+            ctrl.enabled = True
         self.dnsonly_check()
 
 
