@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 PYIDSERVER.PY
 Copyright (C) 2008-2011 by Peter A. Donis
@@ -12,29 +13,33 @@ about it.
 """
 
 import sys
+import os
 import socket
 
-from plib.utils.chatgen import chat_replies as _chat_replies
+from plib.utils.chatgen import chat_replies
 
 
 def do_output(fileobj, s, linesep=True):
+    fileobj.write(s)
     if linesep:
-        fileobj.write("%s\n" % s)
-    else:
-        fileobj.write(s)
+        fileobj.write(os.linesep)
     fileobj.flush()
 
 
-class chat_replies(_chat_replies):
-    # Adds initial output when connection is made
+def output_chat_replies(chat_addr, chat_items, fileobj,
+    start_msg, conn_msg, close_msg):
     
-    def __init__(self, addr, items, fileobj, callback=None):
-        _chat_replies.__init__(self, addr, items, callback)
-        self.fileobj = fileobj
+    class _chat(chat_replies):
+        def __init__(self, addr, items):
+            do_output(fileobj, start_msg)
+            super(_chat, self).__init__(addr, items)
+        def on_connect(self):
+            do_output(fileobj, conn_msg)
+        def on_close(self):
+            do_output(fileobj, close_msg)
     
-    def on_connect(self):
-        do_output(self.fileobj, "Connected ...")
-        do_output(self.fileobj, "Server returned the following:")
+    for reply in _chat(chat_addr, chat_items):
+        do_output(fileobj, reply, False)
 
 
 PROTO_DEFAULT = 'http'
@@ -50,10 +55,11 @@ protocols = {
     'smtp': (25, quitmsgs) }
 
 
-def run_idserver(fileobj, arg, dns_only, protocol, portnum):
+def run_idserver(arg, dns_only, protocol, portnum, fileobj):
+    
     if '://' in arg:
         addrtype, arg = arg.split('://')
-        if (addrtype in protocols):
+        if addrtype in protocols:
             if protocol:
                 do_output(fileobj,
                     "URL includes protocol %s, ignoring specified protocol %s."
@@ -111,15 +117,14 @@ def run_idserver(fileobj, arg, dns_only, protocol, portnum):
         do_output(fileobj, "IP address for %s is %s." % (url, ipaddr))
     
     if not dns_only:
-        do_output(fileobj,
-            "Contacting %s%s%s ..." %
-                (arg, proto_msg, port_msg))
-        for reply in chat_replies((url, portnum), proto_items, fileobj):
-            do_output(fileobj, reply, False)
-        do_output(fileobj, "Connection closed.")
+        output_chat_replies((url, portnum), proto_items, fileobj,
+            "Contacting %s%s%s ..." % (arg, proto_msg, port_msg),
+            "Connected ...%sServer returned the following:%s" %
+                (os.linesep, os.linesep),
+            "Connection closed.")
 
 
-def run_main(outfile, arg, errfile=None,
+def run_main(arg, outfile=None, errfile=None,
         dns_only=False, protocol="", portnum=0):
     """Query server and write results to a file-like object.
     
@@ -146,16 +151,16 @@ def run_main(outfile, arg, errfile=None,
     
     Arguments:
     
-    - ``outfile``: the file-like object for output (actually it
-      can be anything that has ``write`` and ``flush`` methods).
-      Defaults to standard output.
-    
     - ``arg``: a URL string (either an IP address or a host name).
       May include a protocol specifier at the start (e.g., http://),
       and may include a port specifier at the end (e.g., :80). A
       trailing slash, '/', in the URL, and anything after it, are
       treated as a path specifier and ignored.
     
+    - ``outfile``: the file-like object for output (actually it
+      can be anything that has ``write`` and ``flush`` methods).
+      Defaults to standard output.
+    
     - ``errfile``: a file-like object for error output (actually it
       can be anything with a ``write`` method). Defaults to the same
       object as ``outfile``.
@@ -173,34 +178,40 @@ def run_main(outfile, arg, errfile=None,
       as shown in the dictionary above.)
     """
     
+    if outfile is None:
+        outfile = sys.stdout
     if errfile is None:
         errfile = outfile
     try:
-        run_idserver(outfile, arg, dns_only, protocol, portnum)
+        run_idserver(arg, dns_only, protocol, portnum, outfile)
     except ValueError:
-        errfile.write("%s\n" % str(sys.exc_info()[1]))
+        errfile.write("%s%s" % (str(sys.exc_info()[1]), os.linesep))
     except (socket.error, socket.herror, socket.gaierror, socket.timeout):
         exc_type, exc_value, _ = sys.exc_info()
-        errfile.write("%s %s\n" % tuple(map(str, (exc_type, exc_value))))
+        errfile.write("%s %s%s" % tuple(map(str, (exc_type, exc_value))) + (os.linesep,))
 
 
 if __name__ == '__main__':
     from plib.stdlib.options import parse_options
     
-    _, def_dns, def_proto, def_port = run_main.func_defaults
+    _, __, def_dns, def_proto, def_port = run_main.func_defaults
     optlist = (
         ("-l", "--lookup", { 'action': "store_true",
             'dest': "dns_only", 'default': def_dns,
             'help': "Only do DNS lookup, no server query" } ),
-        ("-p", "--protocol", { 'action': "store", 'type': "string",
+        ("-p", "--protocol", { 'action': "store", 'type': str,
             'dest': "protocol", 'default': def_proto,
             'help': "Use the specified protocol to contact the server" } ),
-        ("-r", "--port", { 'action': "store", 'type': "int",
+        ("-r", "--port", { 'action': "store", 'type': int,
             'dest': "portnum", 'default': def_port,
             'help': "Use the specified port number to contact the server" } )
         )
-    arglist = ["URL"]
+    arglist = ["url"]
     
     opts, args = parse_options(optlist, arglist)
-    run_main(sys.stdout, args[0], sys.stderr,
+    # Spot check the parsing results
+    assert opts['dns_only'] == opts.dns_only
+    assert args[0] == args.url
+    
+    run_main(args.url, sys.stdout, sys.stderr,
         opts.dns_only, opts.protocol, opts.portnum)
