@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 Module APP -- GUI Application Classes
 Sub-Package GUI.BASE of Package PLIB -- Python GUI Framework
@@ -10,9 +11,142 @@ See the LICENSE and README files for more information
 Defines the classes that form the basic GUI application framework.
 """
 
+import sys
+import os.path
+
+from plib import ini
+
 from plib.gui.defs import *
 
 
+class PBaseWindowBase(object):
+    """Base class for "window" widgets.
+    
+    This class is mainly for inheritance purposes; it implements
+    the basic window behaviors, but does not have all the extra
+    stuff in ``PTopWindow`` that relates specifically to being an
+    application's main window.
+    """
+    
+    clientwidgetclass = None
+    
+    defaultcaption = "Window"
+    placement = (SIZE_NONE, MOVE_NONE)
+    sizeoffset = 160
+    
+    _clientattrs = ('defaultcaption', 'placement', 'sizeoffset')
+    
+    def __init__(self, parent, cls):
+        self.shown = False
+        
+        # Figure out if parent is another window or the application
+        # (normally only a PTopWindow will have the application as
+        # its parent directly, but we implement the check here
+        # because it's easier)
+        if hasattr(parent, 'app'):
+            self.app = parent.app
+            self._parent = parent
+        elif isinstance(parent, PApplicationBase):
+            self.app = parent
+            self._parent = None
+        else:
+            # This shouldn't happen, but just in case...
+            self.app = None
+            self._parent = None
+        
+        self._set_client_class(cls)
+        
+        self.clientwidget = self.createclient()
+        
+        self.set_caption(self.defaultcaption)
+    
+    def set_caption(self, caption):
+        """Placeholder for derived classes to implement.
+        """
+        raise NotImplementedError
+    
+    def _set_client_class(self, cls):
+        if cls is not None:
+            self.clientwidgetclass = cls
+        if self.clientwidgetclass is not None:
+            cls = self.clientwidgetclass
+            for attrname in self._clientattrs:
+                if hasattr(cls, attrname):
+                    setattr(self, attrname, getattr(cls, attrname))
+                elif not hasattr(self, attrname):
+                    setattr(self, attrname, None)
+    
+    def createclient(self):
+        """Create the client widget if its class is given.
+        """
+        
+        if self.clientwidgetclass is not None:
+            return self.clientwidgetclass(self)
+        return None
+    
+    def get_clientsize(self):
+        """Return tuple of (width, height) needed to wrap client.
+        """
+        c = self.clientwidget
+        return (c.preferred_width(), c.preferred_height())
+    
+    def sizetoscreen(self, maximized=False):
+        """Size the window to the screen.
+        
+        Size the window to be sizeoffset pixels from each screen edge,
+        or maximized if the parameter is True.
+        """
+        raise NotImplementedError
+    
+    def sizetoclient(self, clientwidth, clientheight):
+        """Size the window to a client widget.
+        
+        Size the window to fit the given client width and height.
+        """
+        raise NotImplementedError
+    
+    def center(self):
+        """Center the window in the primary screen.
+        """
+        raise NotImplementedError
+    
+    def init_placement(self):
+        size, pos = self.placement
+        if size == SIZE_CLIENTWRAP:
+            self.sizetoclient(*self.get_clientsize())
+        elif size in (SIZE_MAXIMIZED, SIZE_OFFSET):
+            self.sizetoscreen(size == SIZE_MAXIMIZED)
+        if (pos == MOVE_CENTER) and (size != SIZE_MAXIMIZED):
+            self.center()
+    
+    def show_init(self):
+        """Should always call from derived classes to ensure proper setup.
+        """
+        if not self.shown:
+            # Do placement just before showing for first time
+            self.init_placement()
+            self.shown = True
+    
+    def clientcanclose(self):
+        return (not hasattr(self.clientwidget, 'acceptclose')) \
+            or self.clientwidget.acceptclose()
+    
+    def acceptclose(self):
+        """Return False if window should not close based on current state.
+        """
+        return self.clientcanclose()
+    
+    def _canclose(self):
+        # Internal method, should not be overridden (override acceptclose
+        # to add/modify external behavior)
+        return self.acceptclose()
+    
+    def exit(self):
+        """Placeholder for derived classes to implement.
+        """
+        raise NotImplementedError
+
+
 class PAboutDialogBase(object):
     """Base class for about dialogs.
     
@@ -34,7 +168,37 @@ class PAboutDialogBase(object):
         return super(PAboutDialogBase, self).__getattribute__(name)
 
 
-class PTopWindowBase(object):
+def _munge_prefsdata(prefsdata):
+    # For re-ordering prefs data if the more readable
+    # ordering was used (see PTopWindowBase constructor below)
+    return (prefsdata[0], prefsdata[2], prefsdata[1])
+
+
+def _get_settings(prefsdata):
+    # Only call after ordering has been munged if needed (as above)
+    from plib import ini
+    prefsname, specs, _ = prefsdata
+    inispecs = [(sname, [(oname, otype, default)
+        for oname, otype, default, __ in opts])
+            for sname, _, opts in specs]
+    return ini.PIniFile(prefsname, inispecs)
+
+
+def _fix_prefsdata(settings, prefsdata):
+    # Only call after _get_settings (as above)
+    _, specs, style = prefsdata
+    dlgspecs = []
+    for sname, title, opts in specs:
+        dlgspecs.append((sname, title))
+        dlgspecs.extend(("%s_%s" % (sname, oname), label)
+            for oname, _, __, label in opts)
+    return settings, dict(dlgspecs), style
+
+
+window_optnames = ("left", "top", "width", "height")
+
+
+class PTopWindowBase(PBaseWindowBase):
     """Base class for 'top window' widgets.
     
     A top window is a 'plain' main application window; it has no
@@ -72,118 +236,148 @@ class PTopWindowBase(object):
     screen edge)
     """
     
-    clientwidgetclass = None
     aboutdialogclass = None
     abouttoolkitfunc = None
     
     aboutdata = {}
     prefsdata = None
-    defaultcaption = "Top Window"
-    placement = (SIZE_NONE, MOVE_NONE)
-    sizeoffset = 160
     
-    _clientattrs = ('aboutdata', 'prefsdata',
-        'defaultcaption', 'placement', 'sizeoffset')
+    defaultcaption = "Top Window"
+    
+    _clientattrs = ('aboutdata', 'prefsdata') + PBaseWindowBase._clientattrs
     
     def __init__(self, parent, cls=None):
-        self.shown = False
+        PBaseWindowBase.__init__(self, parent, cls)
         
-        # Figure out if parent is another window or the application
-        if hasattr(parent, 'app'):
-            self.app = parent.app
-            self._parent = parent
-        elif isinstance(parent, PApplicationBase):
-            self.app = parent
-            self._parent = None
-        else:
-            # This shouldn't happen, but just in case...
-            self.app = None
-            self._parent = None
+        self._setup_aboutdata()
+        self._setup_prefsdata()
         
-        self._set_client_class(cls)
-        
-        if 'icon' in self.aboutdata:
-            self.set_iconfile(self.aboutdata['icon'])
-        self.set_caption(self.defaultcaption)
-        
-        self.clientwidget = self.createclient()
         self.prefsdialog = self.createprefsdialog()
     
-    def _set_client_class(self, cls):
-        if cls is not None:
-            self.clientwidgetclass = cls
-        if self.clientwidgetclass is not None:
-            cls = self.clientwidgetclass
-            for attrname in self._clientattrs:
-                if hasattr(cls, attrname):
-                    setattr(self, attrname, getattr(cls, attrname))
-                elif not hasattr(self, attrname):
-                    setattr(self, attrname, None)
+    def get_basename(self):
+        """Return the base name of the application script.
+        """
+        return os.path.splitext(os.path.basename(sys.argv[0]))[0]
+    
+    def _setup_aboutdata(self):
+        if 'icon' in self.aboutdata:
+            self.set_iconfile(self.aboutdata['icon'])
+    
+    def _setup_prefsdata(self):
+        size, pos = self.placement
+        if self.prefsdata:
+            # Support alternate ordering of prefs parameters
+            if isinstance(self.prefsdata[1], int):
+                # Re-order to put the section type flag after the
+                # list of labels (having the list last is more
+                # readable in the class definition, but the actual
+                # dialog constructor wants the flag last)
+                self.prefsdata = _munge_prefsdata(self.prefsdata)
+            prefsdata = self.prefsdata
+        elif (size == SIZE_SETTINGS) or (pos == MOVE_SETTINGS):
+            # Create an empty prefsdata object so we can add the
+            # settings for window coordinates below
+            prefsdata = (
+                self.get_basename(), [], SECTION_GROUPBOX)
+        else:
+            prefsdata = None
+        if prefsdata:
+            # Add the window placement settings if the class fields
+            # for placement are set appropriately
+            if (size == SIZE_SETTINGS) or (pos == MOVE_SETTINGS):
+                prefsdata[1].append(("window", "Window Placement",
+                    [(optname, ini.INI_INTEGER, -1, optname.capitalize())
+                        for optname in window_optnames]))
+            # Now split out settings from prefsdata if a settings
+            # name is given instead of a PIniFile instance
+            if isinstance(prefsdata[0], basestring):
+                self.settings = _get_settings(prefsdata)
+                if self.prefsdata:
+                    self.prefsdata = _fix_prefsdata(self.settings, prefsdata)
+            else:
+                self.settings = prefsdata[0]
+        else:
+            self.settings = None
     
     def set_iconfile(self, iconfile):
         """Placeholder for derived classes to implement.
         """
         raise NotImplementedError
     
-    def set_caption(self, caption):
-        """Placeholder for derived classes to implement.
-        """
-        raise NotImplementedError
-    
-    def createclient(self):
-        """Create the client widget if its class is given."""
-        
-        if self.clientwidgetclass is not None:
-            return self.clientwidgetclass(self)
-        return None
-    
     def createprefsdialog(self):
-        """Create the preferences dialog if data is given."""
+        """Create the preferences dialog if data is given.
+        """
         
-        if (self.prefsdata is not None):
+        if self.prefsdata:
             # This avoids circular imports when this module is first loaded
             from plib.gui import main as gui
             return gui.PPrefsDialog(self, *self.prefsdata)
         return None
     
-    def sizetoscreen(self, maximized=False):
-        """Size the window to the screen.
+    def _size_to_settings(self, width, height):
+        """Size the window to the given width and height (including frame).
+        """
+        raise NotImplementedError
+    
+    def _move_to_settings(self, left, top):
+        """Move the window to the given position (including frame).
+        """
+        raise NotImplementedError
+    
+    def _get_current_geometry(self):
+        """Return the window's current geometry (including frame).
+        """
+        raise NotImplementedError
+    
+    def set_settings_placement(self, setsize, setpos):
+        # Set previous window placement from settings
+        if setsize or setpos:
+            left, top, width, height = tuple(
+                getattr(self.settings, "window_%s" % optname)
+                    for optname in window_optnames)
+            if setsize:
+                self._size_to_settings(width, height)
+            if setpos:
+                self._move_to_settings(left, top)
+    
+    def get_settings_placement(self, setsize, setpos):
+        # Store current window size and position in settings
+        if setsize or setpos:
+            left, top, width, height = self._get_current_geometry()
+            for optname in window_optnames:
+                setattr(self.settings, "window_%s" % optname,
+                    locals()[optname])
+    
+    def get_coordinates(self):
+        """Update settings with current coordinates.
         
-        Size the window to be sizeoffset pixels from each screen edge,
-        or maximized if the parameter is True."""
-        raise NotImplementedError
+        Called by PPrefsDialog before showing the dialog.
+        """
+        size, pos = self.placement
+        self.get_settings_placement(
+            size == SIZE_SETTINGS, pos == MOVE_SETTINGS)
     
-    def sizetoclient(self, clientwidth, clientheight):
-        """Size the window to a client widget.
+    def set_coordinates(self):
+        """Size/move window to coordinates in settings.
         
-        Size the window to fit the given client width and height.
+        Called by PPrefsDialog when Apply or OK is pressed.
+        """
+        size, pos = self.placement
+        self.set_settings_placement(
+            size == SIZE_SETTINGS, pos == MOVE_SETTINGS)
+    
+    def init_placement(self):
+        PBaseWindowBase.init_placement(self)
+        self.set_coordinates()
+    
+    def choose_directory(self, curdir):
+        """Display select folder dialog and return chosen folder.
         """
         raise NotImplementedError
     
-    def center(self):
-        """Center the window in the primary screen.
-        """
-        raise NotImplementedError
-    
-    def get_clientsize(self):
-        """Return tuple of (width, height) needed to wrap client.
-        """
-        c = self.clientwidget
-        return (c.preferred_width(), c.preferred_height())
-    
-    def show_init(self):
-        """Should always call from derived classes to ensure proper setup.
-        """
-        if not self.shown:
-            # Do placement just before showing for first time
-            size, pos = self.placement
-            if size == SIZE_CLIENTWRAP:
-                self.sizetoclient(*self.get_clientsize())
-            elif size in (SIZE_MAXIMIZED, SIZE_OFFSET):
-                self.sizetoscreen(size == SIZE_MAXIMIZED)
-            if (pos == MOVE_CENTER) and (size != SIZE_MAXIMIZED):
-                self.center()
-            self.shown = True
+    def preferences(self):
+        if self.prefsdialog:
+            self.prefsdialog.showdialog()
     
     def about(self):
         if (self.aboutdata is not None) and \
@@ -198,15 +392,12 @@ class PTopWindowBase(object):
         if self.abouttoolkitfunc is not None:
             self.abouttoolkitfunc()
     
-    def acceptclose(self):
-        """Return False if window should not close based on current state.
-        """
-        return True
-    
-    def exit(self):
-        """Placeholder for derived classes to implement.
-        """
-        raise NotImplementedError
+    def _canclose(self):
+        result = PBaseWindowBase._canclose(self)
+        if result and self.settings:
+            self.get_coordinates()
+            self.settings.writeini()
+        return result
 
 
 class PApplicationBase(object):
