@@ -2,7 +2,7 @@
 """
 Module STATUSBAR -- GUI Status Bar Classes
 Sub-Package GUI.BASE of Package PLIB -- Python GUI Framework
-Copyright (C) 2008-2009 by Peter A. Donis
+Copyright (C) 2008-2011 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -10,9 +10,11 @@ See the LICENSE and README files for more information
 Defines the status bar class.
 """
 
+
 class PStatusBarBase(object):
-    """
-    Base class for a status bar with a text area on the left and an
+    """Base class for status bar widget.
+    
+    A standard status bar with a text area on the left and an
     area for custom widgets on the right.
     
     The widgets parameter passed to the constructor should be a
@@ -36,7 +38,8 @@ class PStatusBarBase(object):
                 self.append_widget(widget())
     
     def _add_widget(self, widget, expand=False, custom=True):
-        """ Placeholder for derived classes to implement. """
+        """Placeholder for derived classes to implement
+        """
         raise NotImplementedError
     
     def append_widget(self, wname, widget):
