@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 Module DIALOGS -- Dialog Classes for GUI
 Sub-Package GUI of Package PLIB -- Python GUI Framework
@@ -33,7 +34,7 @@ from plib.gui.defs import *
 # interested in, that's not an issue; YMMV.
 
 
-class PDialogBase(gui.PTopWindow):
+class PDialogBase(gui.PBaseWindow):
     """Base class for dialogs.
     
     Base class for dialogs; assumes that self.defs
@@ -51,7 +52,7 @@ class PDialogBase(gui.PTopWindow):
     def __init__(self, parent, panelclass):
         self._dirty = False
         self._modified = False
-        gui.PTopWindow.__init__(self, parent, panelclass)
+        gui.PBaseWindow.__init__(self, parent, panelclass)
         
         # Catch the main window closing signal so we can close ourselves
         # (some GUI toolkits don't actually require this, but we do it in
@@ -76,10 +77,10 @@ class PDialogBase(gui.PTopWindow):
     def showdialog(self):
         """Populate dialog with data, then show it.
         """
+        self._populate_data()
         if self.shown:
             self._show_window()
         else:
-            self._populate_data()
             self.show_init()
     
     def hidedialog(self):
@@ -255,10 +256,40 @@ class PPrefsDialog(PDialogBase):
         # and it's a PMainWindow--otherwise this connection has to
         # be made by hand after construction)
         if hasattr(parent, 'connectaction'):
-            parent.connectaction(ACTION_PREFS, self.showdialog)
+            if hasattr(parent, 'preferences'):
+                # This should be the normal case
+                target = parent.preferences
+            else:
+                # This is here in case an alternate main window
+                # class is in use that has a connectaction method
+                # but not a preferences method
+                target = self.showdialog
+            parent.connectaction(ACTION_PREFS, target)
         
         # TODO: Fix sizing in wx
     
+    def showdialog(self):
+        """Populate dialog with data, then show it.
+        
+        Note that if our parent is a PTopWindow that is storing
+        its coordinates in settings, we have to update the
+        settings variables first so the shown dialog will reflect
+        the current state.
+        """
+        if self._parent:
+            self._parent.get_coordinates()
+        PDialogBase.showdialog(self)
+    
+    def button_apply(self):
+        """Retrieve dialog data, but keep open.
+        
+        Note that if our parent is a PTopWindow that is storing
+        its coordinates in settings, and.
+        """
+        PDialogBase.button_apply(self)
+        if self._parent:
+            self._parent.set_coordinates()
+    
     def closedialog(self):
         """Save preferences if modified.
         """
