@@ -2,7 +2,7 @@
 """
 Module PANELS -- Dialog Classes for GUI
 Sub-Package GUI of Package PLIB -- Python GUI Framework
-Copyright (C) 2008-2009 by Peter A. Donis
+Copyright (C) 2008-2011 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -19,7 +19,13 @@ from plib.gui import main as gui
 from plib.gui import specs
 from plib.gui.defs import *
 
+
 class PMainPanel(gui.PAutoPanel):
+    """Panel widget specialized to be the client of an app's main window.
+    
+    This widget will also work in any situation where it is a top-level
+    container (e.g., the main panel of a tab in a tab widget).
+    """
     
     baseclass = gui.PAutoPanel # so sub-panels will construct properly
     
