@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 Module GTKAPP -- Python GTK Application Objects
 Sub-Package GUI.TOOLKITS.GTK of Package PLIB -- Python GUI Toolkits
@@ -46,12 +47,27 @@ class PGtkAboutDialog(app.PAboutDialogBase, gtk.AboutDialog):
         self.hide()
 
 
-class _PGtkMainMixin(gtk.Window, _PGtkCommunicator):
-    """Mixin class for GTK top windows and main windows.
+def _gtkfiledialog(parent, title, path, filter, action):
+    dlg = gtk.FileChooserDialog(title, parent, action)
+    if len(path) > 0:
+        dlg.set_current_folder(path)
+    if len(filter) > 0:
+        flt = gtk.FileFilter()
+        flt.add_pattern(filter)
+        dlg.set_filter(flt)
+    result = dlg.run()
+    if result == gtk.RESPONSE_OK:
+        retval = dlg.get_filename()
+    else:
+        retval = ""
+    dlg.destroy()
+    return retval
+
+
+class _PGtkBaseMixin(gtk.Window, _PGtkCommunicator):
+    """Mixin class for Gtk base windows.
     """
     
-    aboutdialogclass = PGtkAboutDialog
-    
     # Define closing signal using 'automagic' class field
     
     # Need to define the 'enter' signal for Entry
@@ -62,9 +78,11 @@ class _PGtkMainMixin(gtk.Window, _PGtkCommunicator):
     def __init__(self):
         gtk.Window.__init__(self, gtk.WINDOW_TOPLEVEL)
         
-        # 'automagic' signal connections
+        # 'automagic' signal connection
         self.setup_notify(SIGNAL_QUERYCLOSE, self.delete_event)
-        self.setup_notify(SIGNAL_BEFOREQUIT, self.destroy_event)
+    
+    def set_caption(self, caption):
+        self.set_title(caption)
     
     def _add_widget(self, widget, x=0, y=0):
         # Only allow adding widgets manually if layout exists
@@ -101,12 +119,6 @@ class _PGtkMainMixin(gtk.Window, _PGtkCommunicator):
     def _hide_window(self):
         gtk.Window.hide(self)
     
-    def set_iconfile(self, iconfile):
-        self.set_icon_from_file(iconfile)
-    
-    def set_caption(self, caption):
-        self.set_title(caption)
-    
     def sizetoscreen(self, maximized):
         if maximized:
             self.maximize()
@@ -136,7 +148,58 @@ class _PGtkMainMixin(gtk.Window, _PGtkCommunicator):
     
     def delete_event(self):
         # 'automagic' method for SIGNAL_QUERYCLOSE
-        return not self.acceptclose()
+        return not self._canclose()
+
+
+class PGtkBaseWindow(_PGtkBaseMixin, app.PBaseWindowBase):
+    """Customized Gtk base window class.
+    """
+    
+    def __init__(self, parent, cls=None):
+        _PGtkBaseMixin.__init__(self)
+        self.vbox = gtk.VBox()
+        self.add(self.vbox)
+        self.vbox.show()
+        
+        app.PBaseWindowBase.__init__(self, parent, cls)
+        self._init_client()
+    
+    def show_init(self):
+        app.PBaseWindowBase.show_init(self)
+        _PGtkBaseMixin.show_init(self)
+
+
+class _PGtkMainMixin(_PGtkBaseMixin):
+    """Mixin class for GTK top windows and main windows.
+    """
+    
+    aboutdialogclass = PGtkAboutDialog
+    
+    def __init__(self):
+        _PGtkBaseMixin.__init__(self)
+        
+        # 'automagic' signal connection
+        self.setup_notify(SIGNAL_BEFOREQUIT, self.destroy_event)
+    
+    def set_iconfile(self, iconfile):
+        self.set_icon_from_file(iconfile)
+    
+    def _size_to_settings(self, width, height):
+        self.set_size_request(width, height)
+    
+    def _move_to_settings(self, left, top):
+        self.move(left, top)
+    
+    def _get_current_geometry(self):
+        # FIXME: The x, y returned by this are always 0, 0
+        # How the fsck am I supposed to find out the window's
+        # coordinates on the screen!@#$%^&*
+        a = self.allocation
+        return a.x, a.y, a.width, a.height
+    
+    def choose_directory(self, curdir):
+        return _gtkfiledialog(self, "Select folder",
+            curdir, "", gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER)
     
     def destroy_event(self):
         # If we're the main window, this is the 'automagic' method for
@@ -147,6 +210,8 @@ class _PGtkMainMixin(gtk.Window, _PGtkCommunicator):
 
 
 class PGtkTopWindow(_PGtkMainMixin, app.PTopWindowBase):
+    """Customized Gtk top window class.
+    """
     
     def __init__(self, parent, cls=None):
         _PGtkMainMixin.__init__(self)
