@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 Module GTKCOMMON -- Python GTK Common Objects
 Sub-Package GUI.TOOLKITS.GTK of Package PLIB -- Python GUI Toolkits
@@ -69,9 +70,10 @@ _gtksignals = {
     SIGNAL_FOCUS_IN: "focus_in_event",
     SIGNAL_FOCUS_OUT: "focus_out_event",
     SIGNAL_LISTSELECTED: "listview_changed",
+    SIGNAL_CELLSELECTED: "table_cell_selected",
     SIGNAL_TABLECHANGED: "table_changed",
-    SIGNAL_TEXTCHANGED: "changed",
-    SIGNAL_TEXTSTATECHANGED: "state_changed",
+    SIGNAL_TEXTCHANGED: "text_changed",
+    SIGNAL_TEXTSTATECHANGED: "textstate_changed", # FIXME: need mechanism to fire this signal
     SIGNAL_EDITCHANGED: "changed",
     SIGNAL_ENTER: "enter_pressed",
     SIGNAL_TABCHANGED: "tab_changed",
@@ -91,11 +93,12 @@ _gtksignals = {
 
 _gtkwrappers = [
     SIGNAL_ACTIVATED, SIGNAL_CLICKED, SIGNAL_TOGGLED,
-    SIGNAL_SELECTED,
-    SIGNAL_LISTSELECTED, SIGNAL_TABLECHANGED,
+    SIGNAL_SELECTED, SIGNAL_LISTSELECTED,
+    SIGNAL_CELLSELECTED, SIGNAL_TABLECHANGED,
     SIGNAL_TEXTCHANGED, SIGNAL_TEXTSTATECHANGED,
     SIGNAL_EDITCHANGED, SIGNAL_ENTER,
     SIGNAL_TABCHANGED]
+
 _gtkplain = [SIGNAL_FOCUS_IN, SIGNAL_FOCUS_OUT,
     SIGNAL_QUERYCLOSE, SIGNAL_CLOSING,
     SIGNAL_HIDDEN, SIGNAL_BEFOREQUIT]
@@ -148,10 +151,10 @@ class _PGtkWidgetBase(object):
         self._widget().queue_draw()
     
     def preferred_width(self):
-        return self._widget().get_size_request()[0]
+        return self._widget().size_request()[0]
     
     def preferred_height(self):
-        return self._widget().get_size_request()[1]
+        return self._widget().size_request()[1]
     
     def set_width(self, width):
         height = self._widget().get_size_request()[1]
