@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 Module GTKEDITCTRL -- Python GTK Editing Widgets
 Sub-Package GUI.TOOLKITS.GTK of Package PLIB -- Python GUI Toolkits
@@ -40,9 +41,10 @@ class PGtkEditBox(gtk.Entry, _PGtkWidget, _PGtkEditMixin,
     fn_set_text = 'set_text'
     
     # Need to define the 'enter' signal for Entry
-    __gsignals__ = { _gtksignals[SIGNAL_ENTER]:
-        (gobject.SIGNAL_RUN_LAST,
-        gobject.TYPE_NONE, ()) }
+    __gsignals__ = {
+        _gtksignals[SIGNAL_ENTER]:
+            (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, ())
+    }
     
     def __init__(self, parent, target=None, geometry=None, expand=True):
         self._edit = self
