@@ -2,7 +2,7 @@
 """
 Module GTKGROUPBOX -- Python Gtk Group Box Widgets
 Sub-Package GUI.TOOLKITS.GTK of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008-2009 by Peter A. Donis
+Copyright (C) 2008-2011 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -15,16 +15,21 @@ pygtk.require('2.0')
 import gtk
 
 from plib.gui._widgets import groupbox
+from plib.gui.defs import *
 
 from _gtkcommon import _PGtkWidget
 
+
 class PGtkGroupBox(gtk.Frame, _PGtkWidget, groupbox.PGroupBoxBase):
     
-    def __init__(self, parent, caption, controls=None, margin=-1, spacing=-1, geometry=None):
+    def __init__(self, parent, caption, controls=None,
+            margin=-1, spacing=-1, geometry=None):
+        
         gtk.Frame.__init__(self)
         self._vbox = gtk.VBox()
         _PGtkWidget.__init__(self, parent, ALIGN_JUST)
-        groupbox.PGroupBoxBase.__init__(self, parent, caption, controls, margin, spacing, geometry)
+        groupbox.PGroupBoxBase.__init__(self, parent, caption, controls,
+            margin, spacing, geometry)
         self.add(self._vbox)
         self._vbox.show()
     
