@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 Module GTKMAINWIN -- Python GTK Main Window Objects
 Sub-Package GUI.TOOLKITS.GTK of Package PLIB -- Python GUI Toolkits
@@ -19,7 +20,7 @@ from plib.gui.defs import *
 from plib.gui._base import mainwin
 
 from _gtkcommon import _gtkicons, _stockidmap
-from _gtkapp import _PGtkMainMixin
+from _gtkapp import _PGtkMainMixin, _gtkfiledialog
 from _gtkaction import PGtkMenu, PGtkToolBar, PGtkAction
 from _gtkstatusbar import PGtkStatusBar
 
@@ -56,33 +57,17 @@ class PGtkMessageBox(mainwin.PMessageBoxBase):
 
 class PGtkFileDialog(mainwin.PFileDialogBase):
     
-    def _gtkfiledialog(self, title, path, filter, action):
-        dlg = gtk.FileChooserDialog(title, self, action)
-        if len(path) > 0:
-            dlg.set_current_folder(path)
-        if len(filter) > 0:
-            flt = gtk.FileFilter()
-            flt.add_pattern(filter)
-            dlg.set_filter(flt)
-        result = dlg.run()
-        if result == gtk.RESPONSE_OK:
-            retval = dlg.get_filename()
-        else:
-            retval = ""
-        dlg.destroy()
-        return retval
-    
     def openfiledialog(self, path, filter):
-        return self._gtkfiledialog("Select file to open",
+        return _gtkfiledialog(self, "Select file to open",
             path, filter, gtk.FILE_CHOOSER_ACTION_OPEN)
     
     def savefiledialog(self, path, filter):
-        return self._gtkfiledialog("Select file to save",
+        return _gtkfiledialog(self, "Select file to save",
             path, filter, gtk.FILE_CHOOSER_ACTION_SAVE)
 
 
 class PGtkMainWindow(_PGtkMainMixin, mainwin.PMainWindowBase):
-    """A customized GTK main window class.
+    """Customized GTK main window class.
     """
     
     menuclass = PGtkMenu
@@ -92,13 +77,13 @@ class PGtkMainWindow(_PGtkMainMixin, mainwin.PMainWindowBase):
     messageboxclass = PGtkMessageBox
     filedialogclass = PGtkFileDialog
     
-    def __init__(self, parent):
+    def __init__(self, parent, cls=None):
         _PGtkMainMixin.__init__(self)
         self.framebox = gtk.VBox()
         self.add(self.framebox)
         self.framebox.show()
         
-        mainwin.PMainWindowBase.__init__(self, parent)
+        mainwin.PMainWindowBase.__init__(self, parent, cls)
         
         self._add_frame_widget(self.menu)
         self._add_frame_widget(self.toolbar)
