@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 Module GTKTABLE -- Python GTK Table Objects
 Sub-Package GUI.TOOLKITS.GTK of Package PLIB -- Python GUI Toolkits
@@ -35,9 +36,13 @@ class PGtkTableEntry(gtk.Entry, _PGtkCommunicator):
         self._c = col
         self._initialized = False  # avoid index out of range on startup
         
-        # The 'table cell changed' signal gets spotted here and forwarded
+        # The table cell signals get spotted here and forwarded
+        self.connect("focus_in_event", self.cellselected)
         self.connect("changed", self.entrychanged)
     
+    def cellselected(self, obj, event):
+        self._t.do_notify(SIGNAL_CELLSELECTED, self._r, self._c)
+    
     def entrychanged(self, obj):
         # FIXME: Figure out why this hack is necessary to avoid index out of
         # range on initial startup when the first changed event fires
@@ -89,10 +94,15 @@ class PGtkTable(gtk.Table, _PGtkClientWidget, table.PTableBase):
     
     labelsclass = PGtkTableLabels
     
-    # Define table changed signal using 'automagic' class field
-    __gsignals__ = { _gtksignals[SIGNAL_TABLECHANGED]:
-        (gobject.SIGNAL_RUN_LAST,
-        gobject.TYPE_NONE, (gobject.TYPE_INT, gobject.TYPE_INT)) }
+    # Define signals using 'automagic' class field
+    __gsignals__ = {
+        _gtksignals[SIGNAL_CELLSELECTED]:
+            (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
+            (gobject.TYPE_INT, gobject.TYPE_INT)),
+        _gtksignals[SIGNAL_TABLECHANGED]:
+            (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
+            (gobject.TYPE_INT, gobject.TYPE_INT))
+    }
     
     _align = ALIGN_JUST # used by PGtkPanel to determine expand/fill
     
