@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 Module KDECOMMON -- Python KDE Common Objects
 Sub-Package GUI.TOOLKITS.KDE of Package PLIB -- Python GUI Toolkits
@@ -88,6 +89,7 @@ _kdesignalmap = {
     SIGNAL_TOGGLED: "clicked()",
     SIGNAL_SELECTED: "activated(int)",
     SIGNAL_LISTSELECTED: "currentChanged(QListViewItem*)",
+    SIGNAL_CELLSELECTED: "currentChanged(int, int)",
     SIGNAL_TABLECHANGED: "valueChanged(int, int)",
     SIGNAL_TEXTCHANGED: "textChanged()",
     SIGNAL_EDITCHANGED: "textChanged(const QString&)",
