@@ -2,7 +2,7 @@
 """
 Module KDETABWIDGET -- Python KDE Tab Widget
 Sub-Package GUI.TOOLKITS.KDE of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008-2009 by Peter A. Donis
+Copyright (C) 2008-2011 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -16,7 +16,9 @@ from plib.gui._widgets import tabwidget
 
 from _kdecommon import _PKDEClientWidget
 
-class PKDETabWidget(kdeui.KTabWidget, _PKDEClientWidget, tabwidget.PTabWidgetBase):
+
+class PKDETabWidget(kdeui.KTabWidget, _PKDEClientWidget,
+        tabwidget.PTabWidgetBase):
     
     widget_class = kdeui.KTabWidget
     
@@ -28,14 +30,12 @@ class PKDETabWidget(kdeui.KTabWidget, _PKDEClientWidget, tabwidget.PTabWidgetBas
         tabwidget.PTabWidgetBase.__init__(self, parent, tabs, target)
     
     def count(self, value):
-        """
-        Method name collision, we want it to be the Python sequence
-        count method here.
-        """
+        # Method name collision, we want it to be the Python sequence
+        # count method here
         return tabwidget.PTabWidgetBase.count(self, value)
     
     def __len__(self):
-        """ Let this method access the KDE tab widget count method. """
+        # Let this method access the KDE tab widget count method
         return kdeui.KTabWidget.count(self)
     
     def _get_tabtitle(self, index):
@@ -57,22 +57,18 @@ class PKDETabWidget(kdeui.KTabWidget, _PKDEClientWidget, tabwidget.PTabWidgetBas
         """ Wrapper for tab changed signal. """
         if self._setting_index:
             self._item = item
-        else:
+        elif self._target:
             self._target(item)
     
     def connect_to(self, target):
-        """
-        Hack to capture double firing of tab changed signal when
-        tab is changed programmatically instead of by user.
-        """
+        # Hack to capture double firing of tab changed signal when
+        # tab is changed programmatically instead of by user.
         self._target = target
         tabwidget.PTabWidgetBase.connect_to(self, self._current_changed)
     
     def set_current_index(self, index):
-        """
-        Wrap the call to avoid double calling of signal handler, then
-        make the call by hand.
-        """
+        # Wrap the call to avoid double calling of signal handler, then
+        # make the call by hand.
         self._setting_index = True
         self.setCurrentPage(index)
         self._setting_index = False
