@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 Module KDE4APP -- Python KDE Application Objects
 Sub-Package GUI.TOOLKITS.KDE of Package PLIB -- Python GUI Toolkits
@@ -47,8 +48,8 @@ def _kdelogo(icon, kaboutdata):
     kaboutdata.setProgramLogo(qt.QVariant(vtype, vptr))
 
 
-class _PKDEMainMixin(kdeui.KMainWindow, _PKDECommunicator):
-    """Mixin class for KDE top windows and main windows.
+class _PKDEBaseMixin(kdeui.KMainWindow, _PKDECommunicator):
+    """Mixin class for KDE base windows.
     """
     
     _closed = False # default for guard to trap close from system menu, see below
@@ -63,9 +64,6 @@ class _PKDEMainMixin(kdeui.KMainWindow, _PKDECommunicator):
     def _hide_window(self):
         kdeui.KMainWindow.hide(self)
     
-    def set_iconfile(self, iconfile):
-        self.setWindowIcon(kdeui.KIcon(qt.QIcon(qt.QPixmap(iconfile))))
-    
     def set_caption(self, caption):
         self.setPlainCaption(caption)
     
@@ -97,16 +95,6 @@ class _PKDEMainMixin(kdeui.KMainWindow, _PKDECommunicator):
         else:
             kdeui.KMainWindow.show(self)
     
-    def about(self):
-        if self.aboutdata is not None:
-            kaboutdata = _kdeparse(self.aboutdata)
-            if 'icon' in self.aboutdata:
-                _kdelogo(self.aboutdata['icon'], kaboutdata)
-            kdeui.KAboutApplicationDialog(kaboutdata).exec_()
-    
-    def about_toolkit(self):
-        kdeui.KHelpMenu(self).aboutKDE()
-    
     def exit(self):
         # Guard traps a close other than from this method, so we don't throw
         # an exception if this method gets called after we close but before
@@ -116,7 +104,7 @@ class _PKDEMainMixin(kdeui.KMainWindow, _PKDECommunicator):
     
     def closeEvent(self, event):
         # 'automagic' code for SIGNAL_QUERYCLOSE
-        if self.acceptclose():
+        if self._canclose():
             self._emit_event(SIGNAL_CLOSING)
             self._closed = True # set guard used above
             event.accept()
@@ -127,6 +115,53 @@ class _PKDEMainMixin(kdeui.KMainWindow, _PKDECommunicator):
         self._emit_event(SIGNAL_HIDDEN)
 
 
+class PKDEBaseWindow(_PKDEBaseMixin, app.PBaseWindowBase):
+    """Customized KDE base window class.
+    """
+    
+    def __init__(self, parent, cls=None):
+        _PKDEBaseMixin.__init__(self)
+        app.PBaseWindowBase.__init__(self, parent, cls)
+        self.setCentralWidget(self.clientwidget)
+    
+    def show_init(self):
+        app.PBaseWindowBase.show_init(self)
+        _PKDEBaseMixin.show_init(self)
+
+
+class _PKDEMainMixin(_PKDEBaseMixin):
+    """Mixin class for KDE top windows and main windows.
+    """
+    
+    def set_iconfile(self, iconfile):
+        self.setWindowIcon(kdeui.KIcon(qt.QIcon(qt.QPixmap(iconfile))))
+    
+    def _size_to_settings(self, width, height):
+        self.resize(width, height)
+    
+    def _move_to_settings(self, left, top):
+        self.move(left, top)
+    
+    def _get_current_geometry(self):
+        p = self.pos()
+        s = self.size()
+        return p.x(), p.y(), s.width(), s.height()
+    
+    def choose_directory(self, curdir):
+        return str(qt.QFileDialog.getExistingDirectory(
+            self, "Select Folder", qt.QString(curdir)))
+    
+    def about(self):
+        if self.aboutdata is not None:
+            kaboutdata = _kdeparse(self.aboutdata)
+            if 'icon' in self.aboutdata:
+                _kdelogo(self.aboutdata['icon'], kaboutdata)
+            kdeui.KAboutApplicationDialog(kaboutdata).exec_()
+    
+    def about_toolkit(self):
+        kdeui.KHelpMenu(self).aboutKDE()
+
+
 class PKDETopWindow(_PKDEMainMixin, app.PTopWindowBase):
     """Customized KDE top window class.
     """
