@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 Module KDE4COMMON -- Python KDE Common Objects
 Sub-Package GUI.TOOLKITS.KDE of Package PLIB -- Python GUI Toolkits
@@ -87,6 +88,7 @@ _kdesignalmap = {
     SIGNAL_TOGGLED: "clicked()", # toggled(bool)?
     SIGNAL_SELECTED: "activated(int)",
     SIGNAL_LISTSELECTED: "currentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*)",
+    SIGNAL_CELLSELECTED: "currentCellChanged(int, int, int, int)",
     SIGNAL_TABLECHANGED: "cellChanged(int, int)",
     SIGNAL_TEXTCHANGED: "textChanged()", # textEdited()?
     SIGNAL_EDITCHANGED: "textChanged(const QString&)", # textEdited(const QString&)?
