@@ -2,7 +2,7 @@
 """
 Module KDE4STATUSBAR -- Python KDE Status Bar Objects
 Sub-Package GUI.TOOLKITS.KDE of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008-2009 by Peter A. Donis
+Copyright (C) 2008-2011 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -14,9 +14,12 @@ from PyKDE4 import kdeui
 
 from plib.gui._base import statusbar
 
+from _kde4common import _PKDEWidgetBase
 from _kde4label import PKDETextLabel
 
-class PKDEStatusBar(kdeui.KStatusBar, statusbar.PStatusBarBase):
+
+class PKDEStatusBar(kdeui.KStatusBar, _PKDEWidgetBase,
+        statusbar.PStatusBarBase):
     
     textareaclass = PKDETextLabel
     
