@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 Module KDETABWIDGET -- Python KDE Tab Widget
 Sub-Package GUI.TOOLKITS.KDE of Package PLIB -- Python GUI Toolkits
@@ -55,11 +56,10 @@ class PKDETabWidget(kdeui.KTabWidget, _PKDEClientWidget,
     
     def _current_changed(self, index):
         # Wrapper for tab changed signal.
-        item = self.widget(index)
         if self._setting_index:
-            self._item = item
+            self._item = self.widget(index)
         elif self._target:
-            self._target(item)
+            self._target(self._item or self.widget(index))
     
     def connect_to(self, target):
         # Hack to capture double firing of tab changed signal when
@@ -75,5 +75,5 @@ class PKDETabWidget(kdeui.KTabWidget, _PKDEClientWidget,
         self._setting_index = True
         self.setCurrentIndex(index)
         self._setting_index = False
-        self._current_changed(self._item)
+        self._current_changed(index)
         self._item = None
