@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 Module QTCOMMON -- Python Qt Common Objects
 Sub-Package GUI.TOOLKITS.QT of Package PLIB -- Python GUI Toolkits
@@ -35,6 +36,7 @@ _qtsignalmap = {
     SIGNAL_TOGGLED: "clicked()",
     SIGNAL_SELECTED: "activated(int)",
     SIGNAL_LISTSELECTED: "currentChanged(QListViewItem*)",
+    SIGNAL_CELLSELECTED: "currentChanged(int, int)",
     SIGNAL_TABLECHANGED: "valueChanged(int, int)",
     SIGNAL_TEXTCHANGED: "textChanged()",
     SIGNAL_EDITCHANGED: "textChanged(const QString&)",
