@@ -2,7 +2,7 @@
 """
 Module QTGROUPBOX -- Python Qt Group Box Widgets
 Sub-Package GUI.TOOLKITS.QT of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008-2009 by Peter A. Donis
+Copyright (C) 2008-2011 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -16,14 +16,19 @@ from plib.gui._widgets import groupbox
 
 from _qtcommon import _PQtWidget
 
+
 class PQtGroupBox(qt.QVGroupBox, _PQtWidget, groupbox.PGroupBoxBase):
     
     widget_class = qt.QVGroupBox
     
-    def __init__(self, parent, caption, controls=None, margin=-1, spacing=-1, geometry=None):
+    def __init__(self, parent, caption, controls=None,
+            margin=-1, spacing=-1, geometry=None):
+        
         qt.QVGroupBox.__init__(self, parent)
-        self.setSizePolicy(qt.QSizePolicy.MinimumExpanding, qt.QSizePolicy.Fixed)
-        groupbox.PGroupBoxBase.__init__(self, parent, caption, controls, margin, spacing, geometry)
+        self.setSizePolicy(qt.QSizePolicy.MinimumExpanding,
+            qt.QSizePolicy.Fixed)
+        groupbox.PGroupBoxBase.__init__(self, parent, caption, controls,
+            margin, spacing, geometry)
     
     def set_caption(self, caption):
         self.setTitle(caption)
