@@ -2,7 +2,7 @@
 """
 Module QTSTATUSBAR -- Python Qt Status Bar Objects
 Sub-Package GUI.TOOLKITS.QT of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008-2009 by Peter A. Donis
+Copyright (C) 2008-2011 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -14,9 +14,11 @@ import qt
 
 from plib.gui._base import statusbar
 
+from _qtcommon import _PQtWidgetBase
 from _qtlabel import PQtTextLabel
 
-class PQtStatusBar(qt.QStatusBar, statusbar.PStatusBarBase):
+
+class PQtStatusBar(qt.QStatusBar, _PQtWidgetBase, statusbar.PStatusBarBase):
     
     textareaclass = PQtTextLabel
     
