@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 Module QT4APP -- Python Qt 4 Application Objects
 Sub-Package GUI.TOOLKITS.QT4 of Package PLIB -- Python GUI Toolkits
@@ -56,12 +57,10 @@ class PQtAboutDialog(app.PAboutDialogBase):
         qt.QMessageBox.about(self.mainwidget, caption, body)
 
 
-class _PQtMainMixin(qt.QMainWindow, _PQtCommunicator):
-    """Mixin class for Qt top windows and main windows.
+class _PQtBaseMixin(qt.QMainWindow, _PQtCommunicator):
+    """Mixin class for Qt base windows.
     """
     
-    aboutdialogclass = PQtAboutDialog
-    
     def _get_w(self):
         return self.width()
     w = property(_get_w)
@@ -72,9 +71,6 @@ class _PQtMainMixin(qt.QMainWindow, _PQtCommunicator):
     def _hide_window(self):
         qt.QMainWindow.hide(self)
     
-    def set_iconfile(self, iconfile):
-        self.setWindowIcon(qt.QIcon(qt.QPixmap(iconfile)))
-    
     def set_caption(self, caption):
         self.setWindowTitle(caption)
     
@@ -111,7 +107,7 @@ class _PQtMainMixin(qt.QMainWindow, _PQtCommunicator):
     
     def closeEvent(self, event):
         # 'automagic' code for SIGNAL_QUERYCLOSE
-        if self.acceptclose():
+        if self._canclose():
             self._emit_event(SIGNAL_CLOSING)
             event.accept()
         else:
@@ -121,6 +117,45 @@ class _PQtMainMixin(qt.QMainWindow, _PQtCommunicator):
         self._emit_event(SIGNAL_HIDDEN)
 
 
+class PQtBaseWindow(_PQtBaseMixin, app.PBaseWindowBase):
+    """Customized Qt base window class.
+    """
+    
+    def __init__(self, parent, cls=None):
+        _PQtBaseMixin.__init__(self)
+        app.PBaseWindowBase.__init__(self, parent, cls)
+        self.setCentralWidget(self.clientwidget)
+    
+    def show_init(self):
+        app.PBaseWindowBase.show_init(self)
+        _PQtBaseMixin.show_init(self)
+
+
+class _PQtMainMixin(_PQtBaseMixin):
+    """Mixin class for Qt top windows and main windows.
+    """
+    
+    aboutdialogclass = PQtAboutDialog
+    
+    def set_iconfile(self, iconfile):
+        self.setWindowIcon(qt.QIcon(qt.QPixmap(iconfile)))
+    
+    def _size_to_settings(self, width, height):
+        self.resize(width, height)
+    
+    def _move_to_settings(self, left, top):
+        self.move(left, top)
+    
+    def _get_current_geometry(self):
+        p = self.pos()
+        s = self.size()
+        return p.x(), p.y(), s.width(), s.height()
+    
+    def choose_directory(self, curdir):
+        return str(qt.QFileDialog.getExistingDirectory(
+            self, "Select Folder", qt.QString(curdir)))
+
+
 class PQtTopWindow(_PQtMainMixin, app.PTopWindowBase):
     """Customized Qt top window class.
     """
