@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 Module QT4COMMON -- Python Qt 4 Common Objects
 Sub-Package GUI.TOOLKITS.QT4 of Package PLIB -- Python GUI Toolkits
@@ -35,6 +36,7 @@ _qtsignalmap = {
     SIGNAL_TOGGLED: "clicked()", # toggled(bool)?
     SIGNAL_SELECTED: "activated(int)",
     SIGNAL_LISTSELECTED: "currentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*)",
+    SIGNAL_CELLSELECTED: "currentCellChanged(int, int, int, int)",
     SIGNAL_TABLECHANGED: "cellChanged(int, int)",
     SIGNAL_TEXTCHANGED: "textChanged()", # textEdited()?
     SIGNAL_EDITCHANGED: "textChanged(const QString&)", # textEdited(const QString&)?
