@@ -2,7 +2,7 @@
 """
 Module QT4GROUPBOX -- Python Qt 4 Group Box Widgets
 Sub-Package GUI.TOOLKITS.QT4 of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008-2009 by Peter A. Donis
+Copyright (C) 2008-2011 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -16,15 +16,20 @@ from plib.gui._widgets import groupbox
 
 from _qt4common import _PQtWidget
 
+
 class PQtGroupBox(qt.QGroupBox, _PQtWidget, groupbox.PGroupBoxBase):
     
     widget_class = qt.QGroupBox
     
-    def __init__(self, parent, caption, controls=None, margin=-1, spacing=-1, geometry=None):
+    def __init__(self, parent, caption, controls=None,
+            margin=-1, spacing=-1, geometry=None):
+        
         qt.QGroupBox.__init__(self, parent)
-        self.setSizePolicy(qt.QSizePolicy.MinimumExpanding, qt.QSizePolicy.Fixed)
+        self.setSizePolicy(qt.QSizePolicy.MinimumExpanding,
+            qt.QSizePolicy.Fixed)
         self._vlayout = qt.QVBoxLayout()
-        groupbox.PGroupBoxBase.__init__(self, parent, caption, controls, margin, spacing, geometry)
+        groupbox.PGroupBoxBase.__init__(self, parent, caption, controls,
+            margin, spacing, geometry)
     
     def set_caption(self, caption):
         self.setTitle(caption)
