@@ -2,7 +2,7 @@
 """
 Module QT4NOTIFY -- Python Qt Common Objects
 Sub-Package GUI.TOOLKITS.QT4 of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008-2009 by Peter A. Donis
+Copyright (C) 2008-2011 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -20,6 +20,7 @@ _qtnotifytypes = {
     NOTIFY_READ: qt.QSocketNotifier.Read,
     NOTIFY_WRITE: qt.QSocketNotifier.Write }
 
+
 class PQtSocketNotifier(_PQtCommunicator, qt.QSocketNotifier):
     
     auto_enable = True
@@ -28,7 +29,8 @@ class PQtSocketNotifier(_PQtCommunicator, qt.QSocketNotifier):
         self._obj = obj
         self.select_fn = select_fn
         self.notify_fn = notify_fn
-        qt.QSocketNotifier.__init__(self, obj.fileno(), _qtnotifytypes[notify_type])
+        qt.QSocketNotifier.__init__(self, obj.fileno(),
+            _qtnotifytypes[notify_type])
         self.setup_notify(SIGNAL_NOTIFIER, self.handle_notify)
     
     def set_enabled(self, enable):
