@@ -2,7 +2,7 @@
 """
 Module QT4STATUSBAR -- Python Qt 4 Status Bar Objects
 Sub-Package GUI.TOOLKITS.QT4 of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008-2009 by Peter A. Donis
+Copyright (C) 2008-2011 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -14,9 +14,11 @@ from PyQt4 import Qt as qt
 
 from plib.gui._base import statusbar
 
+from _qt4common import _PQtWidgetBase
 from _qt4label import PQtTextLabel
 
-class PQtStatusBar(qt.QStatusBar, statusbar.PStatusBarBase):
+
+class PQtStatusBar(qt.QStatusBar, _PQtWidgetBase, statusbar.PStatusBarBase):
     
     textareaclass = PQtTextLabel
     
