@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 Module WXAPP -- Python wxWidgets Application Objects
 Sub-Package GUI.TOOLKITS.WX of Package PLIB -- Python GUI Toolkits
@@ -48,12 +49,10 @@ class PWxAboutDialog(app.PAboutDialogBase, wx.AboutDialogInfo):
         wx.AboutBox(self)
 
 
-class _PWxMainMixin(wx.Frame, _PWxCommunicator):
-    """Mixin class for wxWidgets top windows and main windows.
+class _PWxBaseMixin(wx.Frame, _PWxCommunicator):
+    """Mixin class for wxWidgets base windows.
     """
     
-    aboutdialogclass = PWxAboutDialog
-    
     def _get_w(self):
         return self.GetClientSizeTuple()[0]
     w = property(_get_w)
@@ -64,9 +63,6 @@ class _PWxMainMixin(wx.Frame, _PWxCommunicator):
     def _hide_window(self):
         wx.Frame.Hide(self)
     
-    def set_iconfile(self, iconfile):
-        self.SetIcon(_wx_icon_from_file(iconfile))
-    
     def set_caption(self, caption):
         self.SetTitle(caption)
     
@@ -92,7 +88,7 @@ class _PWxMainMixin(wx.Frame, _PWxCommunicator):
     
     def OnCloseWindow(self, event):
         # 'automagic' method for SIGNAL_QUERYCLOSE
-        if event.CanVeto() and not self.acceptclose():
+        if event.CanVeto() and not self._canclose():
             event.Veto()
         else:
             # Send the closing signal
@@ -102,7 +98,57 @@ class _PWxMainMixin(wx.Frame, _PWxCommunicator):
             self.Destroy()
 
 
+class PWxBaseWindow(_PWxBaseMixin, app.PBaseWindowBase):
+    """Customized wxWidgets base window class.
+    """
+    
+    def __init__(self, parent, cls=None):
+        _PWxBaseMixin.__init__(self, None)
+        app.PBaseWindowBase.__init__(self, parent, cls)
+        
+        # 'automagic' connection
+        self.setup_notify(SIGNAL_QUERYCLOSE, self.OnCloseWindow, False)
+    
+    def show_init(self):
+        app.PBaseWindowBase.show_init(self)
+        _PWxBaseMixin.show_init(self)
+
+
+class _PWxMainMixin(_PWxBaseMixin):
+    """Mixin class for wxWidgets top windows and main windows.
+    """
+    
+    aboutdialogclass = PWxAboutDialog
+    
+    def set_iconfile(self, iconfile):
+        self.SetIcon(_wx_icon_from_file(iconfile))
+    
+    def _size_to_settings(self, width, height):
+        self.SetSizeWH(width, height)
+        self.SetMinSize((width, height))
+    
+    def _move_to_settings(self, left, top):
+        self.SetPosition(wx.Point(left, top))
+    
+    def _get_current_geometry(self):
+        left, top = self.GetPosition()
+        width, height = self.GetSizeTuple()
+        return left, top, width, height
+    
+    def choose_directory(self, curdir):
+        dlg = wx.DirDialog(self._parent, defaultPath=curdir)
+        result = dlg.ShowModal()
+        if result == wx.ID_OK:
+            retval = dlg.GetPath()
+        else:
+            retval = ""
+        dlg.Destroy()
+        return retval
+
+
 class PWxTopWindow(_PWxMainMixin, app.PTopWindowBase):
+    """Customized wxWidgets top window class.
+    """
     
     def __init__(self, parent, cls=None):
         _PWxMainMixin.__init__(self, None)
