@@ -2,7 +2,7 @@
 """
 Module WXCOMBO -- Python wxWidgets Combo Box Widgets
 Sub-Package GUI.TOOLKITS.WX of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008-2009 by Peter A. Donis
+Copyright (C) 2008-2011 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -17,11 +17,13 @@ from plib.gui._widgets import combo
 
 from _wxcommon import _PWxWidget
 
+
 # TODO: determine if simple combo without edit cell can be used
 class PWxComboBox(wx.ComboBox, _PWxWidget, combo.PComboBoxBase):
     
     def __init__(self, parent, sequence=None, target=None, geometry=None):
-        wx.ComboBox.__init__(self, parent, style=(wx.CB_DROPDOWN | wx.CB_READONLY))
+        wx.ComboBox.__init__(self, parent,
+            style=(wx.CB_DROPDOWN | wx.CB_READONLY))
         self._align = ALIGN_LEFT # used by PWxPanel to determine placement
         combo.PComboBoxBase.__init__(self, sequence, target, geometry)
     
