@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 Module WXCOMMON -- Python wxWidgets Common Objects
 Sub-Package GUI.TOOLKITS.WX of Package PLIB -- Python GUI Toolkits
@@ -81,6 +82,7 @@ _wxeventmap = {
     SIGNAL_FOCUS_IN: wx.EVT_SET_FOCUS,
     SIGNAL_FOCUS_OUT: wx.EVT_KILL_FOCUS,
     SIGNAL_LISTSELECTED: wx.EVT_TREE_SEL_CHANGED,
+    SIGNAL_CELLSELECTED: wx.grid.EVT_GRID_SELECT_CELL,
     SIGNAL_TABLECHANGED: wx.grid.EVT_GRID_CELL_CHANGE,
     SIGNAL_TEXTCHANGED: wx.EVT_TEXT,
     SIGNAL_TEXTSTATECHANGED: EVT_TEXT_STATE_CHANGED,
@@ -116,8 +118,30 @@ def wx_listviewchanged_wrapper(self, target):
     return wrapper
 
 
+def wx_cellselected_wrapper(self, target):
+    def wrapper(event):
+        # FIXME: As noted in scrips-edit.py, we have to have hacks
+        # in user code to work around the fact that wx fires this
+        # event and the table changed event out of sequence; when
+        # you press Enter to finish a cell edit, wx in its infinite
+        # wisdom moves the cell cursor to the next cell down, but it
+        # does *NOT* fire the table changed event *before* moving the
+        # cursor; no, it first moves the cursor *AND FIRES THE CELL
+        # SELECTED EVENT*, and THEN it *FIRES THE TABLE CHANGED EVENT
+        # FOR THE CELL THAT IS NO LONGER SELECTED BECAUSE IT MOVED
+        # THE CURSOR BEFORE TELLING USER CODE THAT THE PREVIOUS CELL
+        # HAD BEEN CHANGED* @#$%^&*! Anyway, at some point I may
+        # figure out a way to have the library code here fix this
+        # f**ked event ordering, so user code sees an API that makes
+        # some kind of f**king sense.
+        target(event.GetRow(), event.GetCol())
+        event.Skip(True)
+    return wrapper
+
+
 def wx_tablechanged_wrapper(self, target):
     def wrapper(event):
+        print event, event.GetRow(), event.GetCol()
         target(event.GetRow(), event.GetCol())
     return wrapper
 
@@ -136,6 +160,7 @@ _wxwrappermap = {
     SIGNAL_FOCUS_IN: wx_plain_wrapper,
     SIGNAL_FOCUS_OUT: wx_plain_wrapper,
     SIGNAL_LISTSELECTED: wx_listviewchanged_wrapper,
+    SIGNAL_CELLSELECTED: wx_cellselected_wrapper,
     SIGNAL_TABLECHANGED: wx_tablechanged_wrapper,
     SIGNAL_TEXTCHANGED: wx_plain_wrapper,
     SIGNAL_EDITCHANGED: wx_plain_wrapper,
