@@ -2,7 +2,7 @@
 """
 Module WXSTATUSBAR -- Python wxWidgets Status Bar Objects
 Sub-Package GUI.TOOLKITS.WX of Package PLIB -- Python GUI Toolkits
-Copyright (C) 2008-2009 by Peter A. Donis
+Copyright (C) 2008-2011 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -14,9 +14,11 @@ import wx
 
 from plib.gui._base import statusbar
 
+from _wxcommon import _PWxWidgetBase
 #from _wxlabel import PWxTextLabel
 
-class PWxStatusBar(wx.StatusBar, statusbar.PStatusBarBase):
+
+class PWxStatusBar(wx.StatusBar, _PWxWidgetBase, statusbar.PStatusBarBase):
     
     #textareaclass = PWxTextLabel # FIXME: not needed for wx?
     
