@@ -2,7 +2,7 @@
 """
 Module COMBO -- GUI Combo Box Widgets
 Sub-Package GUI.WIDGETS of Package PLIB -- Python GUI Framework
-Copyright (C) 2008-2009 by Peter A. Donis
+Copyright (C) 2008-2011 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -14,6 +14,7 @@ from plib.stdlib import baselist, SortMixin
 from plib.gui.defs import *
 from plib.gui._widgets import _control
 
+
 class PComboBoxBase(_control._PDialogControl, SortMixin, baselist):
     """
     Combo box that looks like a list of strings.
@@ -36,9 +37,11 @@ class PComboBoxBase(_control._PDialogControl, SortMixin, baselist):
         self.set_current_index(self.index(text))
     
     def current_index(self):
-        """ Placeholder for derived classes to implement. """
+        """Placeholder for derived classes to implement.
+        """
         raise NotImplementedError
     
     def set_current_index(self, index):
-        """ Placeholder for derived classes to implement. """
+        """Placeholder for derived classes to implement.
+        """
         raise NotImplementedError
