@@ -2,7 +2,7 @@
 """
 Module LABEL -- GUI Text Label Widgets
 Sub-Package GUI.WIDGETS of Package PLIB -- Python GUI Framework
-Copyright (C) 2008-2009 by Peter A. Donis
+Copyright (C) 2008-2011 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -12,9 +12,9 @@ Defines the widget classes for text label widgets.
 
 from plib.gui._widgets import _control
 
+
 class PTextLabelBase(_control._PDialogControl):
-    """
-    Base class for a widget that just displays a single line of text.
+    """Base class for widget that displays a single line of text.
     """
     
     def __init__(self, text=None, geometry=None):
@@ -23,9 +23,11 @@ class PTextLabelBase(_control._PDialogControl):
             self.set_text(text)
     
     def get_text(self):
-        """ Placeholder for derived classes to implement. """
+        """Placeholder for derived classes to implement.
+        """
         raise NotImplementedError
     
     def set_text(self, value):
-        """ Placeholder for derived classes to implement. """
+        """Placeholder for derived classes to implement.
+        """
         raise NotImplementedError
