@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 Module LISTVIEW -- GUI Tree/List View Widgets
 Sub-Package GUI.WIDGETS of Package PLIB -- Python GUI Framework
@@ -11,6 +12,7 @@ Defines the widget classes for tree view/list view widgets.
 """
 
 import sys
+import new
 
 from plib.gui.defs import *
 from plib.gui._widgets import _control, _helpers, _signal
@@ -94,6 +96,12 @@ class PListViewMixin(_helpers._PTreeHelper):
     """
     
     def __init__(self, parent, labels=None, data=None):
+        # Some GUI toolkits define a clear method but it
+        # doesn't work reliably, so we insist on using
+        # ours (note that we have to create the bound
+        # method by hand)
+        self.clear = new.instancemethod(
+            _helpers._PTreeHelper.clear, self, self.__class__)
         self._parent = parent
         if not hasattr(self.itemclass, 'listviewclass'):
             self.itemclass.listviewclass = self.__class__
