@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 Module DEFS -- Common GUI Definitions
 Sub-Package GUI of Package PLIB -- Python GUI Framework
@@ -65,9 +66,10 @@ SIGNAL_CLICKED = 101 # widget has been clicked
 SIGNAL_TOGGLED = 102 # on/off widget has been toggled
 SIGNAL_SELECTED = 151 # item in widget has been selected; handler must take index param
 SIGNAL_LISTSELECTED = 161 # list view item has changed; handler must take item param
+SIGNAL_CELLSELECTED = 171 # table current cell has changed; handler must take row, col params
 SIGNAL_FOCUS_IN = 191 # widget has received keyboard focus
 SIGNAL_FOCUS_OUT = 195 # widget has lost keyboard focus
-SIGNAL_TABLECHANGED = 301 # table cell text has changed; handler must take row, col params
+SIGNAL_TABLECHANGED = 301 # table cell text has changed; handler must take row, col params for new and old cells
 SIGNAL_TEXTCHANGED = 401 # text in edit control has been changed
 SIGNAL_TEXTSTATECHANGED = 411 # state of edit control has changed
 SIGNAL_EDITCHANGED = 450 # text in edit box has been changed
@@ -110,6 +112,10 @@ ACTION_ABOUT = 49152
 ACTION_ABOUTTOOLKIT = 49160
 ACTION_EXIT = 65536
 
+# Dummy object to signal new "auto-target-finding" API in specs
+
+AUTO_TARGET = object()
+
 # color constants -- we choose values to make hacks easier :)
 COLORNAMES = ['BLACK',
     'DARKRED', 'RED', # 'LIGHTRED', # FIXME: for some reason this isn't in the standard X11 list
@@ -125,9 +131,11 @@ SIZE_NONE = 0
 SIZE_CLIENTWRAP = 1
 SIZE_MAXIMIZED = 2
 SIZE_OFFSET = 4
+SIZE_SETTINGS = 8
 
 MOVE_NONE = 0
 MOVE_CENTER = 1
+MOVE_SETTINGS = 2
 
 # Socket notifier constants
 NOTIFY_READ = 0
