@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 Module MAIN -- Top-Level GUI Module
 Sub-Package GUI of Package PLIB -- Python GUI Framework
@@ -98,7 +99,7 @@ else:
         ('mainwin',
             ['MessageBox', 'FileDialog', 'MainWindow']),
         ('app',
-            ['TopWindow']) ]
+            ['BaseWindow', 'TopWindow']) ]
     
     # Some items are only present in certain toolkits
     if toolkit in ('KDE', 'KDE4', 'Qt', 'Qt4'):
