@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 Module SPECS -- GUI Specification Helper Module
 Sub-Package GUI of Package PLIB -- Python GUI Framework
@@ -14,7 +15,7 @@ pyidserver-gui.py example program.
 """
 
 from plib.gui import main as gui
-from plib.gui.common import actiondict
+from plib.gui.common import actiondict, AUTO_TARGET
 
 # Control variables for widget geometries; if you want to
 # change these values, you can import specs and mutate them
@@ -72,6 +73,18 @@ labelgeometry = lambda: (None, None, labelwidth, None)
 main_geometry = lambda: (None, None, mainwidth, mainheight)
 
 
+# Convenience function for enabling auto-target functionality
+
+def _adjust_target(target, fstr, name):
+    # Note that "no target" is None, which isn't touched here
+    if target in ('', AUTO_TARGET):
+        newtarget = fstr % name
+        if target == '':
+            return newtarget
+        return (target, newtarget)
+    return target
+
+
 # Convenience functions for building specs
 
 def get_padding(name):
@@ -94,51 +107,41 @@ def get_textlabel(label, name):
 
 
 def get_checkbox(label, name, target=None):
-    if target == '': # don't want to use None since that should mean no target
-        target = '%s_check' % name
     return (checkbox_class,
         (label,),
-        {'target': target},
+        {'target': _adjust_target(target, '%s_check', name)},
         'checkbox_%s' % name)
 
 
 def get_combobox(items, name, target=None):
-    if target == '':
-        target = '%s_selected' % name
     return (combo_class,
         (items,),
-        {'target': target,
+        {'target': _adjust_target(target, '%s_selected', name),
             'geometry': combo_geometry()},
         'combo_%s' % name)
 
 
 def get_editbox(name, target=None, expand=True):
-    if target == '':
-        target = '%s_changed' % name
     return (edit_class,
         (),
-        {'target': target,
+        {'target': _adjust_target(target, '%s_changed', name),
             'geometry': editgeometry(), 'expand': expand},
         'edit_%s' % name)
 
 
 def get_numeditbox(name, target=None, expand=True):
-    if target == '':
-        target = '%s_changed' % name
     return (edit_class,
         (),
-        {'target': target,
+        {'target': _adjust_target(target, '%s_changed', name),
             'geometry': numeditgeometry(), 'expand': expand},
         'edit_%s' % name)
 
 
 def get_listbox(labels, name, target=None):
-    if target == '':
-        target = '%s_selected' % name
     # FIXME: this doesn't appear to properly handle labels with width = -1
     return (listbox_class,
         ([header_class(*args) for args in labels],),
-        {'target': target,
+        {'target': _adjust_target(target, '%s_selected', name),
             'geometry': listboxgeometry()},
         'listbox_%s' % name)
 
@@ -158,41 +161,33 @@ def get_textdisplay(name, text="", scrolling=True):
 
 
 def get_editcontrol(name, target=None, scrolling=True):
-    if target == '':
-        target = '%s_changed' % name
     return (memo_class,
         (),
-        {'target': target,
+        {'target': _adjust_target(target, '%s_changed', name),
             'geometry': main_geometry(), 'scrolling': scrolling},
         'memo_%s' % name)
 
 
 def get_memo(name, target=None, scrolling=True):
-    if target == '':
-        target = '%s_changed' % name
     return (memo_class,
         (),
-        {'target': target,
+        {'target': _adjust_target(target, '%s_changed', name),
             'scrolling': scrolling},
         'memo_%s' % name)
 
 
 def get_listview(labels, name, target=None):
-    if target == '':
-        target = '%s_selected' % name
     # FIXME: this doesn't appear to properly handle labels with width = -1
     return (listview_class,
         ([header_class(*args) for args in labels],),
-        {'target': target},
+        {'target': _adjust_target(target, '%s_selected', name)},
         'listview_%s' % name)
 
 
 def get_button(caption, name, pxname=None, target=''):
-    if target == '':
-        target = name
     return (button_class,
         (caption, pxname),
-        {'target': target,
+        {'target': _adjust_target(target, '%s', name),
             'geometry': button_geometry()},
         'button_%s' % name)
 
@@ -211,7 +206,7 @@ def get_action_button(action, name=None, target=''):
             target = None
     return (button_class,
         (action, ""),
-        {'target': target,
+        {'target': _adjust_target(target, '%s', name),
             'geometry': button_geometry()},
         'button_%s' % name)
 
@@ -247,11 +242,9 @@ def get_tab_panel(contents, align, layout, name):
 
 
 def get_tabwidget(tabs, name, target=None):
-    if target == '':
-        target = '%s_changed' % name
     return (tabwidget_class,
         (tabs,),
-        {'target': target},
+        {'target': _adjust_target(target, '%s_changed', name)},
         'tabs_%s' % name)
 
 
@@ -261,3 +254,77 @@ def get_toplevel_panel(contents, align, layout, name):
         {'align': align, 'layout': layout,
             'margin': panelmargin, 'spacing': panelspacing},
         'panel_%s' % name)
+
+
+### Alternate API (this will become the norm in version 0.8)
+
+def toplevel_panel(align, layout, name, contents):
+    return get_toplevel_panel(contents, align, layout, name)
+
+
+def groupbox(caption, name, contents):
+    return get_groupbox(contents, caption, name)
+
+
+def tabwidget(name, tabs, target=None):
+    return get_tabwidget(tabs, name, target)
+
+
+def midlevel_panel(align, layout, name, contents):
+    return get_midlevel_panel(contents, align, layout, name)
+
+
+def tab_panel(align, layout, name, contents):
+    return get_tab_panel(contents, align, layout, name)
+
+
+def interior_panel(align, layout, name, contents):
+    return get_interior_panel(contents, align, layout, name)
+
+
+# New API methods, use "auto-targeting" by default
+
+def checkbox(label, name, target=AUTO_TARGET):
+    return get_checkbox(label, name, target)
+
+
+def combobox(name, items, target=AUTO_TARGET):
+    return get_combobox(items, name, target)
+
+
+def editbox(name, target=AUTO_TARGET, expand=True):
+    return get_editbox(name, target, expand)
+
+
+def editcontrol(name, target=AUTO_TARGET, scrolling=True):
+    return get_editcontrol(name, target, scrolling)
+
+
+def listbox(name, labels, target=AUTO_TARGET):
+    return get_listbox(labels, name, target)
+
+
+def listview(name, labels, target=AUTO_TARGET):
+    return get_listview(labels, name, target)
+
+
+def memo(name, target=AUTO_TARGET, scrolling=True):
+    return get_memo(name, target, scrolling)
+
+
+def numeditbox(name, target=AUTO_TARGET, expand=True):
+    return get_numeditbox(name, target, expand)
+
+
+# New API methods for controls that don't need or don't
+# use auto-targeting (the latter are the buttons, which
+# should always complain if they don't find event handlers
+# since that's the only point of having them)
+
+action_button = get_action_button
+button = get_button
+label = get_label
+padding = get_padding
+textcontrol = get_textcontrol
+textdisplay = get_textdisplay
+textlabel = get_textlabel
