@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 Sub-Package STDLIB of Package PLIB -- Python Standard Library Extensions
 Copyright (C) 2008-2011 by Peter A. Donis
@@ -34,6 +35,9 @@ function closure -- a reference to ``plib.stdlib.func.partial``,
     provided for convenience since the name is more indicative of
     the usage to some
 
+function fix_newlines -- returns a string with line breaks changed
+    from old_newline to newline.
+
 function gcd -- fast implementation of Euclid's GCD algorithm.
 
 function inrange -- returns index forced to be >= low, <= high.
@@ -62,14 +66,29 @@ function normalize_slice -- returns a list of indexes "covered" by a
     index to which a zero-length slice refers (normalized relative
     to count).
 
-function prod -- returns the product of all items in an iterable.
-
 function slice_len -- returns the "length" of a slice (meaning the
     number of indexes that would be affected if it were used as an
     index into a sequence).
 
+function split_string -- splits a string into three pieces, at the
+    line breaks after the given start string and before the given
+    end string appear. Note edge case behavior: if the start string
+    is not found, the first of the three strings returned will be
+    empty; if the end string is not found, the last of the three
+    will be empty, and if both are not found, the middle of the
+    three strings will be the entire string passed in. This may
+    seem a little strange, but if you think about how you would use
+    this function, it makes sense. (Note also that finding the
+    start string really means that plus finding a newline after it,
+    and finding the end string really means that plus finding a
+    newline before it. This can be tweaked by setting the
+    ``find_newlines`` argument to ``False``.)
+
 functions strtobool, strtodate -- self-explanatory.
 
+constant universal_newline -- string representing the "universal
+    newline" character
+
 function cached_property (and auxiliary class CachedProperty) --
 
 Implementation of a "cached property" descriptor, which
@@ -111,7 +130,6 @@ function upgrade_builtins -- convenience function to ensure
 
 import sys
 import datetime
-from operator import mul
 
 from plib.utils import ModuleProxy
 
@@ -120,25 +138,7 @@ from _paths import *
 from plib.stdlib.func import partial as closure
 
 
-def gcd(x, y):
-    """Return greatest common divisor of x, y.
-    """
-    while x:
-        x, y = y % x, x
-    return y
-
-
-def inrange(index, v1, v2):
-    """Force index to be within the range v1 to v2, and return result.
-    """
-    if v1 < v2:
-        low = v1
-        high = v2
-    else:
-        low = v2
-        high = v1
-    return min(max(index, low), high)
-
+# File iterator utility function
 
 def iterfile(f):
     """Return a generator that yields lines from a file.
@@ -156,6 +156,50 @@ def iterfile(f):
         yield line
 
 
+# Newline handling functions
+
+universal_newline = '\n'
+
+def split_string(s, newline, start, end, find_newlines=True):
+    i = s.find(start)
+    if i < 0:
+        j = s.find(end)
+    else:
+        j = s.find(end, i)
+        if find_newlines:
+            i = s.find(newline, i) + len(newline)
+        else:
+            i += len(start)
+    if (j > -1) and find_newlines:
+        if i > -1:
+            j = s.rfind(newline, i, j)
+        else:
+            j = s.rfind(newline, 0, j)
+    if i < 0 and (j < 0):
+        return "", s, ""
+    if i < 0:
+        return "", s[:j], s[j:]
+    if j < 0:
+        return s[:i], s[i:], ""
+    return s[:i], s[i:j], s[j:]
+
+
+def fix_newlines(s, newline, old_newline=universal_newline):
+    result = newline.join(s.splitlines())
+    if s.endswith(old_newline):
+        return result + newline
+    return result
+
+
+# Math functions
+
+def gcd(x, y):
+    """Return greatest common divisor of x, y.
+    """
+    while x:
+        x, y = y % x, x
+    return y
+
 def lcm(x, y):
     """Return least common multiple of x, y.
     """
@@ -164,6 +208,20 @@ def lcm(x, y):
     return x * y / gcd(x, y)
 
 
+# Sequence/slice handling functions
+
+def inrange(index, v1, v2):
+    """Force index to be within the range v1 to v2, and return result.
+    """
+    if v1 < v2:
+        low = v1
+        high = v2
+    else:
+        low = v2
+        high = v1
+    return min(max(index, low), high)
+
+
 def normalize(count, index):
     """Return index with negative values normalized to count.
     
@@ -246,13 +304,6 @@ def normalize_slice(count, index):
         return range(start, stop, step)
 
 
-def prod(iterable):
-    """Return the product of all items in iterable.
-    """
-    
-    return reduce(mul, iterable, 1)
-
-
 def slice_len(s):
     """Return the number of indexes referenced by a slice.
     
@@ -285,22 +336,24 @@ def slice_len(s):
         return (stop - start) // step
 
 
-def strtobool(s):
+# Type conversion functions
+
+def strtobool(s, falsestr='False', truestr='True'):
     """Return bool from string s interpreting s as a 'Python value string'.
     
     Return None if s is not 'True' or 'False'.
     """
-    
-    return {'False': False, 'True': True}.get(s, None)
+    return {falsestr: False, truestr: True}.get(s, None)
 
 
 def strtodate(s):
     """Return date object from string formatted as date.__str__ would return.
     """
-    
     return datetime.date(*map(int, s.split('-')))
 
 
+# Special decorator
+
 class CachedProperty(object):
     """Non-data descriptor class for cached property.
     
@@ -350,7 +403,8 @@ BUILTIN_NAMES = [
 EXTRA_NAMES = [
     'first',
     'inverted',
-    'last'
+    'last',
+    'prod'
 ]
 
 # This ensures we don't run the upgrade multiple times
@@ -417,6 +471,7 @@ def upgrade_builtins():
     - first
     - inverted
     - last
+    - prod
     """
     
     global _upgraded
