@@ -2,7 +2,7 @@
 """
 Module abstractcontainer
 Sub-Package STDLIB of Package PLIB
-Copyright (C) 2008-2009 by Peter A. Donis
+Copyright (C) 2008-2011 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -15,10 +15,13 @@ from __future__ import generators # to ensure we can use yield in version 2.2
 import sys
 from itertools import izip
 
-from plib.stdlib import any, first, inrange
+from plib.stdlib import inrange, upgrade_builtins
+upgrade_builtins()
+
 
 class abstractcontainer(object):
-    """
+    """Immutable abstract container.
+    
     An abstract class to provide the minimal possible support of the
     Python container protocol. Subclasses can implement just the __len__
     and __getitem__ methods to allow the class to be used in the standard
@@ -31,12 +34,14 @@ class abstractcontainer(object):
     """
     
     def __len__(self):
-        """ Return the number of items in the list. """
+        """Return the number of items in the container.
+        """
         raise NotImplementedError
     
     def __getitem__(self, index):
-        """
-        Get item by index. Negative indexes are relative to end of list.
+        """Get item by index.
+        
+        Negative indexes are relative to end of list.
         Raise IndexError if index is out of range.
         """
         raise NotImplementedError
@@ -61,7 +66,7 @@ class abstractcontainer(object):
         raise TypeError, "object does not support item deletion"
     
     #def __repr__(self):
-    #    return "".join(("[", ", ".join([repr(item) for item in self.__iter__()]), "]"))
+    #    return "".join(("[", ", ".join([repr(item) for item in self]), "]"))
     #
     #__str__ = __repr__
     
@@ -77,39 +82,44 @@ class abstractcontainer(object):
     
     if sys.version_info < (2, 4):
         
-        def __contains__(self, value):
+        # Can't use generator expressions so we need helpers
+        
+        def __contains_helper(self, value):
             for item in self:
-                if item == value:
-                    return True
-            return False
+                yield item == value
+        
+        def __contains__(self, value):
+            return any(self.__contains_helper(value))
     
     else:
         
         def __contains__(self, value):
             return any(item == value for item in self)
     
-    if sys.version_info >= (2, 6):
-        
-        def __reversed__(self):
-            for i in reversed(xrange(len(self))):
-                yield self[i]
+    # We can always provide this since our upgrade_builtins (above) adds
+    # a ``reversed`` builtin function that will use it
+    
+    def __reversed__(self):
+        for i in reversed(xrange(len(self))):
+            yield self[i]
     
     # Need the basic comparison operators
     
     if sys.version_info < (2, 4):
         
-        def __ne__(self, other):
-            if len(other) != len(self):
-                return True
+        def __ne_helper(self, other):
             for x, y in izip(self, other):
-                if x != y:
-                    return True
-            return False
+                yield x != y
+        
+        def __ne__(self, other):
+            return (len(other) != len(self)) or \
+                any(self.__ne_helper(other))
     
     else:
         
         def __ne__(self, other):
-            return (len(other) != len(self)) or any(x != y for x, y in izip(self, other))
+            return (len(other) != len(self)) or \
+                any(x != y for x, y in izip(self, other))
     
     def __eq__(self, other):
         return not self.__ne__(other)
@@ -151,51 +161,37 @@ class abstractcontainer(object):
     
     # These are implemented here because they don't mutate the object
     
+    def index(self, value, start=None, end=None):
+        if start is None:
+            start = 0
+        if end is None:
+            end = len(self)
+        if start < 0:
+            start += len(self)
+        start = inrange(start, 0, len(self))
+        if end < 0:
+            end += len(self)
+        end = inrange(end, 0, len(self))
+        for i in xrange(start, end):
+            if self[i] == value:
+                return i
+        raise ValueError, "sequence item not found"
+    
     if sys.version_info < (2, 4):
         
-        def index(self, value, start=None, end=None):
-            if start is None:
-                start = 0
-            if end is None:
-                end = len(self)
-            if start < 0:
-                start += len(self)
-            start = inrange(start, 0, len(self))
-            if end < 0:
-                end += len(self)
-            end = inrange(end, 0, len(self))
-            for i in xrange(start, end):
-                if self[i] == value:
-                    return i
-            raise ValueError, "sequence item not found"
+        # Can't use a generator expression so we need a helper
+        def __count_helper(self, value):
+            for item in self:
+                yield int(item == value)
         
         def count(self, value):
-            result = 0
-            for item in self:
-                if item == value:
-                    result += 1
-            return result
+            return sum(self.__count_helper(value))
     
     else:
         
-        def index(self, value, start=None, end=None):
-            if start is None:
-                start = 0
-            if end is None:
-                end = len(self)
-            if start < 0:
-                start += len(self)
-            start = inrange(start, 0, len(self))
-            if end < 0:
-                end += len(self)
-            end = inrange(end, 0, len(self))
-            result = first(i for i in xrange(start, end) if self[i] == value)
-            if result is not None:
-                return result
-            raise ValueError, "sequence item not found"
-        
         def count(self, value):
-            return sum(1 for item in self if item == value)
+            return sum(int(item == value) for item in self)
+
 
 try:
     from collections import Sequence
