@@ -2,7 +2,7 @@
 """
 Module COLL -- Convenience Collection Classes
 Sub-Package STDLIB of Package PLIB
-Copyright (C) 2008-2009 by Peter A. Donis
+Copyright (C) 2008-2011 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -16,26 +16,44 @@ each collection to add and retrieve an item from the
 collection). Thus:
 
 fifo -- a deque; 'append' adds to the end of the queue,
-'next' retrieves from the start (i.e., 'popleft').
+    'next' retrieves from the start (i.e., 'popleft').
 
 stack -- a list; 'append' adds to the end of the list,
-'next' retrieves from the end as well (i.e., 'pop').
+    'next' retrieves from the end as well (i.e., 'pop').
+
+Note that the contents of the standard library collections
+module are also available here, so you can just import
+from here instead of having to import both modules. This
+includes equivalents of classes that appear in later
+Python versions (defaultdict and/or namedtuple) for earlier
+Python versions that don't include them.
 """
 
-import collections
+import sys
+from collections import *
 
-class fifo(collections.deque):
-    """
-    A first-in, first-out data queue.
+try:
+    defaultdict
+except NameError:
+    from _defaultdict import defaultdict
+
+try:
+    namedtuple
+except NameError:
+    from _namedtuple import namedtuple
+
+
+class fifo(deque):
+    """A first-in, first-out data queue.
     """
     
     def __init__(self, *args, **kwargs):
         self.next = self.popleft
-        collections.deque.__init__(self, *args, **kwargs)
+        deque.__init__(self, *args, **kwargs)
+
 
 class stack(list):
-    """
-    A last-in, first-out data queue.
+    """A last-in, first-out data queue.
     """
     
     def __init__(self, *args, **kwargs):
