@@ -2,7 +2,7 @@
 """
 Module PersistentSocketMixin
 Sub-Package STDLIB.IO.ASYNC of Package PLIB
-Copyright (C) 2008-2009 by Peter A. Donis
+Copyright (C) 2008-2011 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -15,13 +15,13 @@ read/write handling can be mixed in.
 from plib.stdlib.io.socket import ConnectMixin
 from plib.stdlib.io.async import AsyncConnectMixin, PersistentMixin
 
+
 class PersistentSocketMixin(AsyncConnectMixin, ConnectMixin, PersistentMixin):
-    """
-    Mixin class for persistent, full-duplex asynchronous socket
-    I/O. Can be used for both clients and servers, but intended
+    """Mixin class for persistent, full-duplex asynchronous socket I/O.
+    
+    Can be used for both clients and servers, but intended
     mainly for clients that need connect functionality. (For
     server-side persistent sockets, you should normally use the
     ``PersistentRequestHandler`` class with ``SocketServer``.)
     """
-    
     pass
