@@ -2,7 +2,7 @@
 """
 Module RequestBase
 Sub-Package STDLIB.IO.ASYNC of Package PLIB
-Copyright (C) 2008-2009 by Peter A. Donis
+Copyright (C) 2008-2011 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -10,14 +10,19 @@ See the LICENSE and README files for more information
 This module contains the asynchronous RequestBase class.
 """
 
+import sys
+
 from plib.stdlib.io.socket import BaseRequest
 from plib.stdlib.io.async import SocketBase
 
+
 class RequestBase(BaseRequest, SocketBase):
-    """
-    Asynchronous socket I/O set up to serve as a request handler.
+    """Base class for async request handler.
     """
     
     def __init__(self, request, client_addr, server):
         BaseRequest.__init__(self, request, client_addr, server)
         SocketBase.__init__(self, request)
+        
+        # If we're being called at all, we must be connected
+        self.handle_connect()
