@@ -2,7 +2,7 @@
 """
 Module SerialBase
 Sub-Package STDLIB.IO.ASYNC of Package PLIB
-Copyright (C) 2008-2009 by Peter A. Donis
+Copyright (C) 2008-2011 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -13,9 +13,8 @@ This module contains the asynchronous SerialBase class.
 from plib.stdlib.io.serial import SerialData
 from plib.stdlib.io.async import SerialDispatcher
 
+
 class SerialBase(SerialData, SerialDispatcher):
+    """Serial async I/O class with data handling.
     """
-    Serial async I/O class with data handling.
-    """
-    
     pass
