@@ -2,7 +2,7 @@
 """
 Module SerialBase
 Sub-Package STDLIB.IO.BLOCKING of Package PLIB
-Copyright (C) 2008-2009 by Peter A. Donis
+Copyright (C) 2008-2011 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -12,9 +12,9 @@ This module contains the blocking I/O SerialBase class.
 
 from plib.stdlib.io.serial import SerialData, SerialIOBase
 
+
 class SerialBase(SerialData, SerialIOBase):
-    """
-    Base class for blocking serial I/O.
+    """Base class for blocking serial I/O with data handling.
     """
     
     blocking_mode = True
