@@ -2,7 +2,7 @@
 """
 Module BaseRequest
 Sub-Package STDLIB.IO.SOCKET of Package PLIB
-Copyright (C) 2008-2009 by Peter A. Donis
+Copyright (C) 2008-2011 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -10,9 +10,9 @@ See the LICENSE and README files for more information
 This module contains the socket I/O BaseRequest class.
 """
 
+
 class BaseRequest(object):
-    """
-    Base socket I/O class set up to serve as a request handler.
+    """Base socket I/O class set up to serve as a request handler.
     """
     
     def __init__(self, request, client_addr, server):
