@@ -1,41 +1,48 @@
 #!/usr/bin/env python
 """
 STDLIB_ABSTRACT_TESTLIB.PY -- utility module for common 'abstract' container object tests
-Copyright (C) 2008-2009 by Peter A. Donis
+Copyright (C) 2008-2011 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
 
-This module contains common code for the 'abstract container' types in plib.stdlib.
-Code is taken from the seq_tests, list_tests, test_tuple, and test_list modules
-in the Python test package; however, not all of the 'standard' sequence type tests
-are implemented, only those which test 'generic' behaviors that are emulated by
-the plib classes.
+This module contains common code for the 'abstract container' types in
+plib.stdlib. Code is taken from the seq_tests, list_tests, test_tuple,
+and test_list modules in the Python test package; however, not all of the
+'standard' sequence type tests are implemented, only those which test
+'generic' behaviors that are emulated by the plib classes.
 """
 
 import sys
 import unittest
 
+
 # Helper functions to allow us to test subscripting
 
 def getitem_helper(seq, index):
     return seq.__getitem__(index)
 
+
 def getitem_helper2(seq, index):
     return seq[index]
 
+
 def setitem_helper(seq, index, value):
     seq.__setitem__(index, value)
 
+
 def setitem_helper2(seq, index, value):
     seq[index] = value
 
+
 def delitem_helper(seq, index=None):
     seq.__delitem__(index)
 
+
 def delitem_helper2(seq, index):
     del seq[index]
 
+
 # The actual test cases
 
 class ImmutableSequenceTest(unittest.TestCase):
@@ -472,6 +479,7 @@ class ImmutableSequenceTest(unittest.TestCase):
         self.assertEqual(list(reversed(self.type2test())),
                          self.type2test())
 
+
 class FixedLengthSequenceTest(ImmutableSequenceTest):
     
     def test_setitem(self):
@@ -722,6 +730,7 @@ class FixedLengthSequenceTest(ImmutableSequenceTest):
         a.reverse()
         self.assertEqual(a, self.type2test())
 
+
 class MutableSequenceTest(FixedLengthSequenceTest):
     
     def test_index_list(self):
