@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 TEST_STDLIB.PY -- test script for sub-package STDLIB of package PLIB
 Copyright (C) 2008-2011 by Peter A. Donis
@@ -11,7 +12,7 @@ This script contains unit tests for the PLIB.STDLIB sub-package.
 
 import unittest
 
-from plib.stdlib import cached_property
+from plib.stdlib import cached_property, fix_newlines, split_string
 
 
 class CachedPropertyTest(object):
