@@ -2,7 +2,7 @@
 """
 Module CLASSES -- Common XML Classes
 Sub-Package XML of Package PLIB -- Python XML and XSLT Utilities
-Copyright (C) 2008-2009 by Peter A. Donis
+Copyright (C) 2008-2011 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -25,6 +25,7 @@ from plib import utils
 from plib.xml import io
 from plib.xml.defs import *
 
+
 # 'Attribute property' functions
 
 def _getprop(propname, form=None):
@@ -36,6 +37,7 @@ def _getprop(propname, form=None):
             return self.get(propname)
     return _getfunc
 
+
 def _setprop(propname, form=None):
     if form is not None:
         def _setfunc(self, value):
@@ -45,8 +47,10 @@ def _setprop(propname, form=None):
             self.set(propname, value)
     return _setfunc
 
+
 def attrib_prop(propname):
-    """
+    """Make XML attribute propname appear as Python property.
+    
     Sets up XML attribute propname as an attribute of the
     Python element instance, so instead of
     
@@ -68,7 +72,10 @@ def attrib_prop(propname):
     by the calling program.
     """
     
-    return property(_getprop(propname), _setprop(propname))
+    return property(
+        _getprop(propname),
+        _setprop(propname))
+
 
 def _strint(s):
     if s is None:
@@ -76,8 +83,10 @@ def _strint(s):
     else:
         return int(s)
 
+
 def attrib_prop_int(propname):
-    """
+    """Make XML attribute propname appear as Python integer.
+    
     Sets up XML attribute propname as an integer attribute
     of the Python element instance, so property values appear
     as Python ints instead of strings. Note that we use the
@@ -85,7 +94,10 @@ def attrib_prop_int(propname):
     non-existent attribute gives zero value).
     """
     
-    return property(_getprop(propname, _strint), _setprop(propname, str))
+    return property(
+        _getprop(propname, _strint),
+        _setprop(propname, str))
+
 
 def _boolstr(flag):
     if flag is True:
@@ -95,6 +107,7 @@ def _boolstr(flag):
     else:
         return None
 
+
 def _strbool(s):
     if s == "yes":
         return True
@@ -103,8 +116,10 @@ def _strbool(s):
     else:
         return None
 
+
 def attrib_prop_bool(propname):
-    """
+    """Make XML attribute propname appear as Python bool.
+    
     Sets up XML attribute propname as a boolean attribute
     of the Python element instance, so property values appear
     as Python True/False instead of strings "yes" and "no".
@@ -112,15 +127,23 @@ def attrib_prop_bool(propname):
     appear as None, *not* False.
     """
     
-    return property(_getprop(propname, _strbool), _setprop(propname, _boolstr))
+    return property(
+        _getprop(propname, _strbool),
+        _setprop(propname, _boolstr))
+
 
 # Dictionary of functions vs. type constants
-attrfuncs = {ATTR_STR: attrib_prop, ATTR_INT: attrib_prop_int, ATTR_BOOL: attrib_prop_bool}
+attrfuncs = {
+    ATTR_STR: attrib_prop,
+    ATTR_INT: attrib_prop_int,
+    ATTR_BOOL: attrib_prop_bool
+}
+
 
 class AttrsMeta(type):
-    """
-    Metaclass to automatically add XML 'attribute properties'
-    using the above attrib_prop functions. Looks in the 'attrs' class
+    """Metaclass to automatically add XML 'attribute properties'.
+    
+    Uses the above attrib_prop functions. Looks in the 'attrs' class
     field for a dict of XML attribute names mapped to property
     types; each name then becomes an attrib_prop of the corresponding
     type. Inspired by the 'autoprop' metaclass in Guido's new-style
@@ -147,10 +170,12 @@ class AttrsMeta(type):
                     attrtype = value[0]
                 else:
                     attrtype = value
-                # Allow for type entries to be lists of allowed strings; note
-                # that since list objects aren't hashable we need the extra first
-                # isinstance test to avoid a TypeError
-                if not (isinstance(attrtype, int) and (attrtype in attrfuncs)):
+                # Allow for type entries to be lists of allowed strings;
+                # note that since list objects aren't hashable we need
+                # the extra first isinstance test to avoid a TypeError
+                if not (isinstance(attrtype, int) and 
+                        (attrtype in attrfuncs)):
+                    
                     attrtype = ATTR_STR
                 setattr(cls, name, attrfuncs[attrtype](name))
     
@@ -159,7 +184,8 @@ class AttrsMeta(type):
     # them here we don't have to use the classmethod decorator
     
     def xmlattrs(cls):
-        """
+        """Return dict of all XML attributes in inheritance tree.
+        
         Return a complete dict of all XML attributes for
         this class (including ones inherited from bases--the
         'attrs' attribute of a given class by itself only
@@ -170,9 +196,10 @@ class AttrsMeta(type):
         
         return utils.recursedict(cls, 'attrs')
 
+
 class Attrs(object):
-    """
-    Mixin class for XML tags with automatic 'attribute properties'.
+    """Mixin class for XML tags with automatic 'attribute properties'.
+    
     We want to keep this functionality separate from the subtag
     and root tag functionality below, so this class needs to be a
     mixin, but we can't derive it from etree.ElementBase because we
@@ -185,23 +212,30 @@ class Attrs(object):
     
     attrs = {}
 
+
 ### XML custom element classes with DTD generation. ###
 
 class BaseElement(etree.ElementBase):
     """ Base element class. """
     pass
 
+
 dtdelement = "<!ELEMENT %s %s>"
 
 dtdattlist = "<!ATTLIST %s\n%s>"
 
-dtdattrs = {ATTR_STR: "CDATA", ATTR_INT: ("CDATA", 0), ATTR_BOOL: (["yes", "no"], False)}
+dtdattrs = {
+    ATTR_STR: "CDATA",
+    ATTR_INT: ("CDATA", 0),
+    ATTR_BOOL: (["yes", "no"], False)
+}
+
 
 class TagMeta(AttrsMeta):
-    """
-    Metaclass to automatically construct more useful class fields for
-    XML tag classes, and to provide DTD generation functionality based
-    on class fields.
+    """Metaclass to automatically construct XML tag class fields.
+    
+    Automatically construct more useful class fields for XML tag classes,
+    and to provide DTD generation functionality based on class fields.
     
     The automatic constructions which are performed on class
     initialization are:
@@ -244,7 +278,8 @@ class TagMeta(AttrsMeta):
             cls.sep = "|"
     
     def xmlsubtags(cls):
-        """
+        """Return list of all XML attributes in inheritance tree.
+        
         Return a complete list of all XML subtags and their
         tag classes (including ones inherited from bases--the
         'subtags' attribute of a given class by itself only
@@ -255,7 +290,8 @@ class TagMeta(AttrsMeta):
         return utils.recurselist(cls, 'subtags')
     
     def dtdsubtags(cls):
-        """
+        """Return list of all DTD subtags in inheritance tree.
+        
         Return a complete list of 2-tuples for this tag's subtags
         for DTD generation. The default is for this to be the same
         as the recursive 'subtags' field above, but derived tag
@@ -265,7 +301,8 @@ class TagMeta(AttrsMeta):
         return cls.xmlsubtags()
     
     def tagdict_subtags(cls):
-        """
+        """Return list of all tagdict subtags in inheritance tree.
+        
         Return a complete list of 2-tuples for this tag's subtags
         for tag dictionary generation (see build_tagdict below).
         The default is to return the same list of subtags as for
@@ -275,7 +312,8 @@ class TagMeta(AttrsMeta):
         return cls.dtdsubtags()
     
     def dtdattr(cls, attrname, attrentry):
-        """
+        """Return DTD attribute entry format string.
+        
         Return the appropriate attribute entry format string
         for attrname, constructed from attrentry information.
         The entry should be either a single value giving the
@@ -331,24 +369,25 @@ class TagMeta(AttrsMeta):
                 attrdefault = "no"
         
         # Format string default if it's not a generic
-        if not (isinstance(attrdefault, basestring) and attrdefault.startswith("#")):
+        if not (isinstance(attrdefault, basestring) and
+                attrdefault.startswith("#")):
+            
             attrdefault = '"%s"' % attrdefault
         
         # Return the formatted attribute entry string
         return '  %s %s %s' % (attrname, attrtypestr, attrdefault)
     
     def attlist(cls):
-        """
-        Return the DTD attribute list for this tag.
+        """Return the DTD attribute list for this tag.
         """
         
         return "\n".join([cls.dtdattr(attrname, attrentry) \
             for attrname, attrentry in cls.xmlattrs().iteritems()])
     
     def dtdsubtag(cls, tagname):
-        """
-        Return the appropriate subtag string for tagname, using
-        the maybe, some, and any class fields to determine if
+        """Return the appropriate subtag string for tagname.
+        
+        Uses the maybe, some, and any class fields to determine if
         a suffix should be added to the tag name.
         """
         
@@ -361,12 +400,14 @@ class TagMeta(AttrsMeta):
         return tagname
     
     def subtaglist(cls):
-        """
-        Return the DTD subtag list for this tag, and/or appropriate
-        string values for other types of content. Note that the
-        substr class field, if non-empty, overrides all other ways
-        of specifying the element content. The pcdata class field
-        determines if character data is acceptable as well as
+        """Return the DTD subtag list for this tag.
+        
+        May return other appropriate string values for other types
+        of content.
+        
+        Note that the substr class field, if non-empty, overrides all
+        other ways of specifying the element content. The pcdata class
+        field determines if character data is acceptable as well as
         subtags, and the dtdsubtags class method (see above) is
         called to get the list of allowed sub-elements.
         """
@@ -379,15 +420,16 @@ class TagMeta(AttrsMeta):
             pre = []
         subtags = cls.dtdsubtags()
         if subtags:
-            return (cls.sep.join(pre + [cls.dtdsubtag(tagname) for tagname, _ in subtags]), cls.end)
+            return (cls.sep.join(pre + [cls.dtdsubtag(tagname)
+                for tagname, _ in subtags]), cls.end)
         if pre:
             return (pre[0], "")
         return "EMPTY"
     
     def dtdentry(cls, tagname, done):
-        """
-        Return a string containing the DTD entry for this tag,
-        recursively including subtag entries before this tag's
+        """Return a string containing the DTD entry for this tag.
+        
+        Recursively includes subtag entries before this tag's
         ELEMENT and ATTLIST entries. The done parameter is
         used to track already emitted tag names so they are
         not emitted again.
@@ -419,10 +461,9 @@ class TagMeta(AttrsMeta):
             setattr(cls, attrname, [])
         getattr(cls, attrname).extend(seq)
 
+
 class Tag(BaseElement):
-    """
-    Base class for deriving custom element classes with more
-    automatic functionality.
+    """Base class for deriving 'automated' custom element classes.
     """
     
     __metaclass__ = TagMeta
@@ -443,18 +484,19 @@ class Tag(BaseElement):
     # Convenience methods
     
     def xnode(self, expr):
-        """ Quick way to get the node instead of a list when there's just one. """
+        """Quick way to get the node instead of a list when there's just one.
+        """
         return self.xpath(expr)[0]
     
     def subelement(self, tagname):
-        """ Quick way to create a sub-element and add it to the tree. """
+        """Quick way to create a sub-element and add it to the tree.
+        """
         self.append(self.makeelement(tagname))
         return self[-1]
 
+
 class RootMeta(TagMeta):
-    """
-    Metaclass to add some useful class methods for DTD
-    generation.
+    """Metaclass to add class methods for DTD generation.
     
     The DTD for the entire XML file of which the tag class is
     the root node is returned as a string by the dtdgen method.
@@ -475,7 +517,8 @@ class RootMeta(TagMeta):
         return ""
     
     def dtdgen(cls):
-        """
+        """Automatic DTD generation method.
+        
         Automatically generate a DTD for the XML file for
         which this is a root node. Return the DTD as a string.
         """
@@ -483,9 +526,10 @@ class RootMeta(TagMeta):
         return "\n".join([cls.dtdheader(), cls.dtdstart(), cls.dtdimports(),
             cls.dtdentry(cls.rootname, []), cls.dtdend()])
 
+
 class RootTag(Tag):
-    """
-    Base class for custom element classes for XML root nodes.
+    """Base class for custom element classes for XML root nodes.
+    
     The rootname class field, if it is not null, is used
     to determine the node name of the root node; this
     is used both by the tagdict and for DTD generation.
@@ -495,6 +539,7 @@ class RootTag(Tag):
     
     rootname = ""
 
+
 def build_tagdict(klass, tagdict):
     for subname, k in klass.tagdict_subtags():
         # Prevent infinite recursion if there are circular
@@ -504,10 +549,11 @@ def build_tagdict(klass, tagdict):
         if recurse:
             build_tagdict(k, tagdict)
 
+
 class TreeMeta(type):
-    """
-    Metaclass for XML tree encapsulation. This metaclass
-    generates the tagdict by walking the tree of tags from
+    """Metaclass for XML tree encapsulation.
+    
+    Generates the tagdict by walking the tree of tags from
     the root node class. The tagdict is used for parsing
     to enable custom element classes. The make_dtd class
     method is also provided to save the DTD to a filename.
@@ -526,10 +572,11 @@ class TreeMeta(type):
         if klass is not None:
             io._writefilename(filename, klass.dtdgen())
 
+
 class Tree(object):
-    """
-    Base class encapsulating XML tree, including parsing,
-    serialization, and dtd generation.
+    """Base class encapsulating XML tree
+    
+    Includes parsing, serialization, and dtd generation.
     """
     
     __metaclass__ = TreeMeta
@@ -549,38 +596,31 @@ class Tree(object):
         self.lookup = self.tagdict
     
     def _set_tree(self, fn, arg):
-        """
-        Set the XML tree and root node using the given parse function,
-        with our lookup (defaults to our tagdict) and whitespace stripping.
+        """Set the XML tree and root node using the given parse function.
+        
+        Use our lookup (defaults to our tagdict) and whitespace stripping.
         """
         
         self.tree = fn(arg, look=self.lookup, strip=self.strip, val=self.val)
         self.root = self.tree.getroot()
     
     def parse(self, s):
+        """Load XML tree from string.
         """
-        Load XML tree from string.
-        """
-        
         self._set_tree(io.parseString, s)
     
     def load_from(self, filename):
+        """Load XML tree from filename.
         """
-        Load XML tree from filename.
-        """
-        
         self._set_tree(io.parseFile, filename)
     
     def serialize(self):
+        """Serialize XML tree to string with given encoding and indentation.
         """
-        Serialize XML tree to string with given encoding and indentation.
-        """
-        
-        return io.toString(self.tree, self.encoding, self.indent, self.decl, self.doctype)
+        return io.toString(self.tree,
+            self.encoding, self.indent, self.decl, self.doctype)
     
     def save_to(self, filename):
+        """Save XML tree to filename with given encoding and indentation.
         """
-        Save XML tree to filename with given encoding and indentation.
-        """
-        
         io._writefilename(filename, self.serialize())
