@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 """
 SETUP-GUI script for Package PLIB
-Copyright (C) 2008-2009 by Peter A. Donis
+Copyright (C) 2008-2011 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -72,6 +72,10 @@ try:
     KDE4_PRESENT = True
 except ImportError:
     pass
+except RuntimeError, e:
+    if 'PyQt4.QtCore' in str(e):
+        # This will happen if Qt 3 and Qt 4 are both present
+        KDE4_PRESENT = True
 
 module_vars = ['QT_PRESENT', 'KDE_PRESENT', 'GTK_PRESENT', 'WX_PRESENT',
     'QT4_PRESENT', 'KDE4_PRESENT']
